@@ -116,16 +116,19 @@ nsFilePicker.prototype = {
   set files(a) { throw "readonly property"; },
   get files()  { return this.mFilesEnumerator; },
 
-  /* readonly attribute nsIFileURL fileURL; */
+  /* readonly attribute nsIURI fileURL; */
   set fileURL(a) { throw "readonly property"; },
   get fileURL()  {
-    if (this.mFilesEnumerator) {
+    if (this.mFileURL)
+      return this.mFileURL;
+
+    if (!this.mFilesEnumerator)
+      return null;
+
       var ioService = Components.classes["@mozilla.org/network/io-service;1"]
                     .getService(Components.interfaces.nsIIOService);
-      var url       = ioService.newFileURI(this.file);
-      return url;
-    }
-    return null;
+
+    return this.mFileURL = ioService.newFileURI(this.file);
   },
 
   /* attribute wstring defaultString; */
@@ -162,7 +165,7 @@ nsFilePicker.prototype = {
     }
     if (filterMask & nsIFilePicker.filterImages) {
       this.appendFilter(bundle.GetStringFromName("imageTitle"),
-                   bundle.GetStringFromName("imageFilter"));
+                   "*.jpg; *.jpeg; *.gif; *.png; *.bmp; *.ico"); // XXX 528755
     }
     if (filterMask & nsIFilePicker.filterXML) {
       this.appendFilter(bundle.GetStringFromName("xmlTitle"),
@@ -172,6 +175,7 @@ nsFilePicker.prototype = {
       this.appendFilter(bundle.GetStringFromName("xulTitle"),
                    bundle.GetStringFromName("xulFilter"));
     }
+    this.mAllowURLs = !!(filterMask & nsIFilePicker.filterAllowURLs);
     if (filterMask & nsIFilePicker.filterApps) {
       // We use "..apps" as a special filter for executable files
       this.appendFilter(bundle.GetStringFromName("appsTitle"),
@@ -193,8 +197,7 @@ nsFilePicker.prototype = {
         iid.equals(nsISupports))
       return this;
 
-    Components.returnCode = Components.results.NS_ERROR_NO_INTERFACE;
-    return null;
+    throw Components.results.NS_ERROR_NO_INTERFACE;
   },
 
   show: function() {
@@ -207,6 +210,7 @@ nsFilePicker.prototype = {
     o.filters = new Object();
     o.filters.titles = this.mFilterTitles;
     o.filters.types = this.mFilters;
+    o.allowURLs = this.mAllowURLs;
     o.retvals = new Object();
 
     var parent;
@@ -247,6 +251,7 @@ nsFilePicker.prototype = {
 
       this.mFilterIndex = o.retvals.filterIndex;
       this.mFilesEnumerator = o.retvals.files;
+      this.mFileURL = o.retvals.fileURL;
       lastDirectory = o.retvals.directory;
       return o.retvals.buttonStatus;
     } catch(ex) { dump("unable to open file picker\n" + ex + "\n"); }
@@ -272,9 +277,9 @@ function (compMgr, fileSpec, location, type)
 
     compMgr.registerFactoryLocation(FILEPICKER_CID,
                                     "FilePicker JS Component",
-//@line 278 "/usr/obj/i386/mozilla-thunderbird-2.0.0.23p1/mozilla/xpfe/components/filepicker/src/nsFilePicker.js.in"
+//@line 283 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mozilla/toolkit/components/filepicker/src/nsFilePicker.js.in"
                                     "",
-//@line 280 "/usr/obj/i386/mozilla-thunderbird-2.0.0.23p1/mozilla/xpfe/components/filepicker/src/nsFilePicker.js.in"
+//@line 285 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mozilla/toolkit/components/filepicker/src/nsFilePicker.js.in"
                                     fileSpec,
                                     location,
                                     type);
