@@ -1,4 +1,4 @@
-/* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
+/* -*- Mode: JavaScript; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /* ***** BEGIN LICENSE BLOCK *****
  * Version: MPL 1.1/GPL 2.0/LGPL 2.1
  *
@@ -20,6 +20,7 @@
  * the Initial Developer. All Rights Reserved.
  *
  * Contributor(s):
+ *   Joachim Herb <herb@leo.org>
  *
  * Alternatively, the contents of this file may be used under the terms of
  * either the GNU General Public License Version 2 or later (the "GPL"), or
@@ -35,14 +36,28 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-pref("general.useragent.extra.thunderbird", "Thunderbird/2.0.0.23");
-//@line 39 "/usr/obj/ports/mozilla-thunderbird-2.0.0.23p1/mozilla/mail/app/profile/all-thunderbird.js"
+//@line 40 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
+
+//@line 46 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
+
+pref("general.useragent.extra.thunderbird", "Thunderbird/3.1.1");
 
 pref("general.useragent.locale", "en-US");
-//@line 41 "/usr/obj/ports/mozilla-thunderbird-2.0.0.23p1/mozilla/mail/app/profile/all-thunderbird.js"
 pref("general.skins.selectedSkin", "classic/1.0");
 
-//@line 47 "/usr/obj/ports/mozilla-thunderbird-2.0.0.23p1/mozilla/mail/app/profile/all-thunderbird.js"
+//@line 56 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
+
+pref("mail.rights.version", 0);
+
+// Don't show the about:rights notification in debug or non-official builds.
+//@line 66 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
+
+// gtk2 (*nix) lacks transparent/translucent drag support (bug 376238), so we
+// want to disable it so people can see where they are dragging things.
+// (Stock gtk drag icons will be used instead.)
+//@line 71 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
+pref("nglayout.enable_drag_images", false);
+//@line 73 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
 
 // App-specific update preferences
 
@@ -68,30 +83,27 @@ pref("app.update.mode", 1);
 pref("app.update.silent", false);
 
 // Update service URL:
-pref("app.update.url", "https://aus2.mozilla.org/update/1/%PRODUCT%/%VERSION%/%BUILD_ID%/%BUILD_TARGET%/%LOCALE%/%CHANNEL%/update.xml");
-pref("app.update.vendorName.override", "Mozilla");
+pref("app.update.url", "https://aus2.mozillamessaging.com/update/3/%PRODUCT%/%VERSION%/%BUILD_ID%/%BUILD_TARGET%/%LOCALE%/%CHANNEL%/%OS_VERSION%/%DISTRIBUTION%/%DISTRIBUTION_VERSION%/update.xml");
 
 // URL user can browse to manually if for some reason all update installation
 // attempts fail.  TODO: Change this URL
-pref("app.update.url.manual", "http://%LOCALE%.www.mozilla.com/%LOCALE%/%APP%/");
+pref("app.update.url.manual", "http://www.mozillamessaging.com/%LOCALE%/%APP%/");
 // A default value for the "More information about this update" link
 // supplied in the "An update is available" page of the update wizard. 
-pref("app.update.url.details", "http://%LOCALE%.www.mozilla.com/%LOCALE%/%APP%/releases/");
+pref("app.update.url.details", "http://www.mozillamessaging.com/%LOCALE%/%APP%/releases/");
 // User-settable override to app.update.url for testing purposes.
 //pref("app.update.url.override", "");
 
-// Interval: Time between checks for a new version (in seconds)
-//           default=1 day
-pref("app.update.interval", 86400);
-// Interval: Time before prompting the user to download a new version that 
-//           is available (in seconds) default=1 day
-pref("app.update.nagTimer.download", 86400);
-// Interval: Time before prompting the user to restart to install the latest
-//           download (in seconds) default=30 minutes
-pref("app.update.nagTimer.restart", 1800);
+// Interval: Time before prompting the user again to restart to install the
+//           latest download (in seconds) default=1 day
+pref("app.update.nagTimer.restart", 86400);
 // Interval: When all registered timers should be checked (in milliseconds)
-//           default=5 seconds
+//           default=10 minutes
 pref("app.update.timer", 600000);
+// Give the user x seconds to react before showing the big UI. default=12 hrs
+pref("app.update.promptWaitTime", 43200);
+// Show the Update Checking/Ready UI when the user was idle for x seconds
+pref("app.update.idletime", 60);
 
 // Whether or not we show a dialog box informing the user that the update was
 // successfully applied. This is off in Firefox by default since we show a 
@@ -101,7 +113,10 @@ pref("app.update.timer", 600000);
 pref("app.update.showInstalledUI", false);
 
 // Release notes URL
-pref("app.releaseNotesURL", "http://%LOCALE%.www.mozilla.com/%LOCALE%/%APP%/%VERSION%/releasenotes/");
+pref("app.releaseNotesURL", "http://live.mozillamessaging.com/%APP%/releasenotes?locale=%LOCALE%&version=%VERSION%&os=%OS%&buildid=%APPBUILDID%");
+
+// Base URL for web-based support pages.
+pref("app.support.baseURL", "http://support.live.mozillamessaging.com/%LOCALE%/%APP%/%APPBUILDID%/");
 
 // Blocklist preferences
 pref("extensions.blocklist.enabled", true);
@@ -124,17 +139,31 @@ pref("extensions.logging.enabled", false);
 //  .. etc ..
 //
 pref("extensions.update.enabled", true);
-pref("extensions.update.url", "chrome://mozapps/locale/extensions/extensions.properties");
+pref("extensions.update.url", "https://versioncheck.addons.mozilla.org/update/VersionCheck.php?reqVersion=%REQ_VERSION%&id=%ITEM_ID%&version=%ITEM_VERSION%&maxAppVersion=%ITEM_MAXAPPVERSION%&status=%ITEM_STATUS%&appID=%APP_ID%&appVersion=%APP_VERSION%&appOS=%APP_OS%&appABI=%APP_ABI%&locale=%APP_LOCALE%&currentAppVersion=%CURRENT_APP_VERSION%&updateType=%UPDATE_TYPE%");
 
 pref("extensions.update.interval", 86400);  // Check for updates to Extensions and 
-                                            // Themes every week
+                                            // Themes every day
 // Non-symmetric (not shared by extensions) extension-specific [update] preferences
 pref("extensions.getMoreExtensionsURL", "https://%LOCALE%.add-ons.mozilla.com/%LOCALE%/%APP%/%VERSION%/extensions/");
 pref("extensions.getMoreThemesURL", "https://%LOCALE%.add-ons.mozilla.com/%LOCALE%/%APP%/%VERSION%/themes/");
+pref("extensions.getMorePluginsURL", "https://%LOCALE%.add-ons.mozilla.com/%LOCALE%/%APP%/%VERSION%/plugins/");
 pref("extensions.dss.enabled", false);          // Dynamic Skin Switching                                               
 pref("extensions.dss.switchPending", false);    // Non-dynamic switch pending after next
 
+pref("extensions.{972ce4c6-7e08-4474-a285-3208198ce6fd}.name", "chrome://messenger/locale/messenger.properties");
+pref("extensions.{972ce4c6-7e08-4474-a285-3208198ce6fd}.description", "chrome://messenger/locale/messenger.properties");
+
+// Preferences for the Get Add-ons pane
+pref("extensions.getAddons.showPane", true);
+pref("extensions.getAddons.browseAddons", "https://%LOCALE%.add-ons.mozilla.com/%LOCALE%/%APP%");
+pref("extensions.getAddons.maxResults", 5);
+pref("extensions.getAddons.recommended.browseURL", "https://%LOCALE%.add-ons.mozilla.com/%LOCALE%/%APP%/recommended");
+pref("extensions.getAddons.recommended.url", "https://services.addons.mozilla.org/%LOCALE%/%APP%/api/%API_VERSION%/list/featured/all/10/%OS%/%VERSION%");
+pref("extensions.getAddons.search.browseURL", "https://%LOCALE%.add-ons.mozilla.com/%LOCALE%/%APP%/search?q=%TERMS%");
+pref("extensions.getAddons.search.url", "https://services.addons.mozilla.org/%LOCALE%/%APP%/api/%API_VERSION%/search/%TERMS%/all/10/%OS%/%VERSION%");
+
 pref("xpinstall.whitelist.add", "update.mozilla.org");
+pref("xpinstall.whitelist.add.36", "getpersonas.com");
 pref("xpinstall.whitelist.add.103", "addons.mozilla.org");
 
 pref("mail.shell.checkDefaultClient", true);
@@ -145,12 +174,6 @@ pref("mail.biff.alert.show_preview", true);
 pref("mail.biff.alert.show_subject", true);
 pref("mail.biff.alert.show_sender",  true);
 
-// Folder Pane View
-// 0 == All Folders
-// 1 == Unread Folders
-// 2 == Favorite Folders
-// 3 == Most Recently Used Folders
-pref("mail.ui.folderpane.view", 0);
 pref("mail.folder.views.version", 0);
 
 // target folder URI used for the last move or copy
@@ -158,83 +181,74 @@ pref("mail.last_msg_movecopy_target_uri", "");
 // last move or copy operation was a move
 pref("mail.last_msg_movecopy_was_move", true);
 
-//@line 165 "/usr/obj/ports/mozilla-thunderbird-2.0.0.23p1/mozilla/mail/app/profile/all-thunderbird.js"
+//@line 199 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
 pref("browser.preferences.instantApply", true);
-//@line 170 "/usr/obj/ports/mozilla-thunderbird-2.0.0.23p1/mozilla/mail/app/profile/all-thunderbird.js"
+//@line 204 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
 pref("browser.preferences.animateFadeIn", false);
-//@line 172 "/usr/obj/ports/mozilla-thunderbird-2.0.0.23p1/mozilla/mail/app/profile/all-thunderbird.js"
+//@line 206 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
+
+pref("browser.download.show_plugins_in_list", false);
+pref("browser.download.hide_plugins_without_extensions", true);
 
 pref("accessibility.typeaheadfind", false);
 pref("accessibility.typeaheadfind.timeout", 5000);
 pref("accessibility.typeaheadfind.linksonly", false);
 pref("accessibility.typeaheadfind.flashBar", 1);
 
+pref("mail.close_message_window.on_delete", false);
+
+// Number of lines of To/CC/BCC address headers to show before "more"
+// truncates the list.
+pref("mailnews.headers.show_n_lines_before_more", 1);
+
+// Thunderbird wants to show the migration assistant on upgrade by default.
+pref("mail.ui.show.migration.on.upgrade", true);
+
+/////////////////////////////////////////////////////////////////
+// Overrides of the core mailnews.js prefs
 /////////////////////////////////////////////////////////////////
-// Overrides of the seamonkey suite mailnews.js prefs
-///////////////////////////////////////////////////////////////// 
-pref("mail.showFolderPaneColumns", false); // setting to true will allow total/unread/size columns
 pref("mail.showCondensedAddresses", true); // show the friendly display name for people I know
 
 // hidden pref for changing how we present attachments in the message pane
-pref("mailnews.attachments.display.largeView", true); 
+pref("mailnews.attachments.display.largeView", false);
 pref("mail.pane_config.dynamic",            0);
-pref("mailnews.reuse_thread_window2", true);
-pref("mail.spam.display.sanitize", true); // sanitize the HTML in spam messages
-pref("mail.standalone", true); 
+pref("mailnews.reuse_thread_window2",     true);
 pref("editor.singleLine.pasteNewlines", 4);  // substitute commas for new lines in single line text boxes
 
-// make messages available for Thunderbird's spotlight importer.
-//@line 196 "/usr/obj/ports/mozilla-thunderbird-2.0.0.23p1/mozilla/mail/app/profile/all-thunderbird.js"
-
 // hidden pref to ensure a certain number of headers in the message pane
 // to avoid the height of the header area from changing when headers are present / not present
 pref("mailnews.headers.minNumHeaders", 0); // 0 means we ignore this pref
 
-pref("mail.compose.dontWarnMail2Newsgroup", false);
+// 0=no header, 1="<author> wrote:", 2="On <date> <author> wrote:"
+// 3="<author> wrote On <date>:", 4=user specified
+pref("mailnews.reply_header_type", 2);
 
-pref("network.cookie.cookieBehavior", 3); // 0-Accept, 1-dontAcceptForeign, 2-dontUse, 3-p3p
+pref("mail.operate_on_msgs_in_collapsed_threads", true);
+pref("mail.warn_on_collapsed_thread_operation", true);
+
+// only affects cookies from RSS articles
+// 0-Accept, 1-dontAcceptForeign, 2-dontUse
+pref("network.cookie.cookieBehavior", 0);
+
+// clear the SeaMonkey pref, so we don't hear about how we don't have a chrome
+// package registered for editor-region while opening about:config
+pref("editor.throbber.url", "");
+
+// 0=as attachment 2=default forward as inline with attachments
+pref("mail.forward_message_mode", 2);
+
+// 0=ask, 1=plain, 2=html, 3=both
+pref("mail.default_html_action", 3);
 
 /////////////////////////////////////////////////////////////////
-// End seamonkey suite mailnews.js pref overrides
+// End core mailnews.js pref overrides
 ///////////////////////////////////////////////////////////////// 
 
 /////////////////////////////////////////////////////////////////
-// Overrides for generic app behavior from the seamonkey suite's all.js
+// Overrides for generic app behavior from the core all.js
 /////////////////////////////////////////////////////////////////
 
-// l12n and i18n
-pref("intl.charsetmenu.mailedit", "chrome://global/locale/intl.properties");
-pref("intl.accept_languages", "chrome://global/locale/intl.properties");
-// collationOption is only set on linux for japanese. see bug 18338 and 62015
-// we need to check if this pref is still useful.
-pref("intl.collationOption",  "chrome://global-platform/locale/intl.properties");
-pref("intl.charsetmenu.browser.static", "chrome://global/locale/intl.properties");
-pref("intl.charsetmenu.browser.more1",  "chrome://global/locale/intl.properties");
-pref("intl.charsetmenu.browser.more2",  "chrome://global/locale/intl.properties");
-pref("intl.charsetmenu.browser.more3",  "chrome://global/locale/intl.properties");
-pref("intl.charsetmenu.browser.more4",  "chrome://global/locale/intl.properties");
-pref("intl.charsetmenu.browser.more5",  "chrome://global/locale/intl.properties");
-pref("intl.charsetmenu.browser.unicode",  "chrome://global/locale/intl.properties");
-pref("intl.charset.detector", "chrome://global/locale/intl.properties");
-pref("intl.charset.default",  "chrome://global-platform/locale/intl.properties");
-pref("font.language.group", "chrome://global/locale/intl.properties");
-pref("intl.menuitems.alwaysappendaccesskeys","chrome://global/locale/intl.properties");
-pref("intl.menuitems.insertseparatorbeforeaccesskeys","chrome://global/locale/intl.properties");
-
-pref("signon.rememberSignons",              true);
-pref("signon.expireMasterPassword",         false);
-pref("signon.SignonFileName",               "signons.txt");
-pref("signon.SignonFileName2",              "signons2.txt");
-
 pref("browser.hiddenWindowChromeURL", "chrome://messenger/content/hiddenWindow.xul");
-pref("network.search.url","http://cgi.netscape.com/cgi-bin/url_search.cgi?search=");
-
-pref("general.startup.browser",             false);
-pref("general.startup.mail",                false);
-pref("general.startup.news",                false);
-pref("general.startup.editor",              false);
-pref("general.startup.compose",             false);
-pref("general.startup.addressbook",         false);
 
 pref("offline.startup_state",            2);
 // 0 Ask before sending unsent messages when going online
@@ -246,14 +260,15 @@ pref("offline.send.unsent_messages",            0);
 // 1 Always synchronize the offline store when going offline
 // 2 Never synchronize the offline store when going offline
 pref("offline.download.download_messages",  0);
-pref("offline.prompt_synch_on_exit",            true);
 
-//@line 262 "/usr/obj/ports/mozilla-thunderbird-2.0.0.23p1/mozilla/mail/app/profile/all-thunderbird.js"
+//@line 282 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
 pref("offline.autoDetect", false);
-//@line 264 "/usr/obj/ports/mozilla-thunderbird-2.0.0.23p1/mozilla/mail/app/profile/all-thunderbird.js"
+//@line 288 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
 
 // Expose only select protocol handlers. All others should go
 // through the external protocol handler route.
+// If you are changing this list, you may need to also consider changing the
+// list in nsMsgContentPolicy::IsExposedProtocol.
 pref("network.protocol-handler.expose-all", false);
 pref("network.protocol-handler.expose.mailto", true);
 pref("network.protocol-handler.expose.news", true);
@@ -263,6 +278,11 @@ pref("network.protocol-handler.expose.imap", true);
 pref("network.protocol-handler.expose.addbook", true);
 pref("network.protocol-handler.expose.pop", true);
 pref("network.protocol-handler.expose.mailbox", true);
+// Although we allow these to be exposed internally, there are various places
+// (e.g. message pane) where we may divert them out to external applications.
+pref("network.protocol-handler.expose.about", true);
+pref("network.protocol-handler.expose.http", true);
+pref("network.protocol-handler.expose.https", true);
 
 // suppress external-load warning for standard browser schemes
 pref("network.protocol-handler.warn-external.http", false);
@@ -285,20 +305,21 @@ pref("xpinstall.dialog.progress.chrome", "chrome://mozapps/content/extensions/ex
 pref("xpinstall.dialog.progress.type.skin", "Extension:Manager"); 
 pref("xpinstall.dialog.progress.type.chrome", "Extension:Manager");
 
+pref("browser.display.auto_quality_min_font_size", 0);
+
+pref("view_source.syntax_highlight", false);
 /////////////////////////////////////////////////////////////////
-// End seamonkey suite all.js pref overrides
+// End core all.js pref overrides
 ///////////////////////////////////////////////////////////////// 
 
 /////////////////////////////////////////////////////////////////
 // Generic browser related prefs. 
-// XXX: Need to scrub these to see which ones thunderbird really needs...
 /////////////////////////////////////////////////////////////////
-pref("browser.startup.homepage",	   "chrome://navigator-region/locale/region.properties");
 pref("browser.cache.memory.capacity",       4096);
-pref("browser.chrome.site_icons", true);
-pref("browser.chrome.favicons", false);
+pref("browser.send_pings", false);
 pref("browser.chrome.toolbar_tips",         true);
 pref("browser.xul.error_pages.enabled", true);
+pref("browser.xul.error_pages.expert_bad_cert", false);
 
 // Attachment download manager settings
 pref("mail.attachment.store.version", 0);
@@ -308,63 +329,31 @@ pref("browser.download.manager.showAlertOnComplete", false);
 pref("browser.download.manager.showAlertInterval", 2000);
 pref("browser.download.manager.retention", 1);
 pref("browser.download.manager.showWhenStarting", true);
-pref("browser.download.manager.useWindow", true);
 pref("browser.download.manager.closeWhenDone", true);
 pref("browser.download.manager.openDelay", 100);
 pref("browser.download.manager.focusWhenStarting", false);
 pref("browser.download.manager.flashCount", 0);
+pref("browser.download.manager.addToRecentDocs", true);
 
 pref("javascript.options.showInConsole",    true);
 
-pref("network.enableIDN",                   false); // Turn on/off IDN (Internationalized Domain Name) resolution
-pref("wallet.captureForms",                 true);
-pref("wallet.enabled",                      true);
-pref("wallet.crypto",                       false); 
-pref("wallet.crypto.autocompleteoverride",  false); // Ignore 'autocomplete=off' - available only when wallet.crypto is enabled. 
-pref("wallet.namePanel.hide",               false);
-pref("wallet.addressPanel.hide",            false);
-pref("wallet.phonePanel.hide",              false);
-pref("wallet.creditPanel.hide",             false);
-pref("wallet.employPanel.hide",             false);
-pref("wallet.miscPanel.hide",               false);
-
 // -- folders (Mac: these are binary aliases.)
 pref("mail.signature_file",             "");
 pref("mail.directory",                  "");
 pref("news.directory",                  "");
-pref("autoupdate.enabled",              true);
-pref("browser.editor.disabled", false);
 pref("spellchecker.dictionary", "");
 // Dictionary download preference
-pref("spellchecker.dictionaries.download.url", "https://%LOCALE%.add-ons.mozilla.com/%LOCALE%/thunderbird/%VERSION%/dictionaries/");
+pref("spellchecker.dictionaries.download.url", "https://%LOCALE%.add-ons.mozilla.com/%LOCALE%/%APP%/%VERSION%/dictionaries/");
 
 // profile.force.migration can be used to bypass the migration wizard, forcing migration from a particular
 // mail application without any user intervention. Possible values are: 
 // dogbert (4.x), seamonkey (mozilla suite), eudora, oexpress, outlook. 
 pref("profile.force.migration", "");
 
-// Customizable toolbar stuff
-pref("custtoolbar.personal_toolbar_folder", "");
-
-// XXXbsmedberg why are changing the default value here?
-// ------------------
-//  Numeral Style
-// ------------------
-// 1 = regularcontextnumeralBidi *
-// 2 = hindicontextnumeralBidi
-// 3 = arabicnumeralBidi
-// 4 = hindinumeralBidi
-pref("bidi.numeral", 1);
-
 // prefs to control the mail alert notification
 pref("alerts.slideIncrementTime", 50);
 pref("alerts.totalOpenTime", 3000);
 
-// 0 opens the download manager
-// 1 opens a progress dialog
-// 2 and other values, no download manager, no progress dialog. 
-pref("browser.downloadmanager.behavior", 1);
-
 // analyze urls in mail messages for scams
 pref("mail.phishing.detection.enabled", true);
 // If phishing detection is enabled, allow fine grained control
@@ -392,11 +381,133 @@ pref("browser.safebrowsing.provider.0.reportPhishURL", "http://{moz:locale}.phis
 // FAQ URL
 pref("browser.safebrowsing.warning.infoURL", "http://%LOCALE%.www.mozilla.com/%LOCALE%/firefox/phishing-protection/");
 
-//@line 407 "/usr/obj/ports/mozilla-thunderbird-2.0.0.23p1/mozilla/mail/app/profile/all-thunderbird.js"
-// For the download dialog
-pref("browser.download.progressDnldDialog.enable_launch_reveal_buttons", false);
-pref("browser.urlbar.clickSelectsAll", false);
-//@line 412 "/usr/obj/ports/mozilla-thunderbird-2.0.0.23p1/mozilla/mail/app/profile/all-thunderbird.js"
-
 // prevent status-bar spoofing even if people are foolish enough to turn on JS
 pref("dom.disable_window_status_change",          true);
+
+// For the Empty Junk/Trash confirmation dialogs.
+pref("mail.emptyJunk.dontAskAgain", false);
+pref("mail.emptyTrash.dontAskAgain", false);
+
+// If a message is opened using Enter or a double click, what should we do?
+// 0 - open it in a new window
+// 1 - open it in an existing window
+// 2 - open it in a new tab
+pref("mail.openMessageBehavior", 2);
+pref("mail.openMessageBehavior.version", 0);
+// If messages or folders are opened using the context menu or a middle click,
+// should we open them in the foreground or in the background?
+pref("mail.tabs.loadInBackground", true);
+
+// Tabs
+pref("mail.tabs.tabMinWidth", 100);
+pref("mail.tabs.tabMaxWidth", 250);
+pref("mail.tabs.tabClipWidth", 140);
+pref("mail.tabs.autoHide", false);
+pref("mail.tabs.closeWindowWithLastTab", true);
+
+// Where to show tab close buttons:
+// 0 - active tab only
+// 1 - all tabs until tabClipWidth is reached, then active tab only
+// 2 - no close buttons
+// 3 - at the end of the tabstrip
+pref("mail.tabs.closeButtons", 1);
+
+// The breakpad report server to link to in about:crashes
+pref("breakpad.reportURL", "http://crash-stats.mozilla.com/report/index/");
+
+// OS Integrated Search and Indexing
+//@line 449 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
+
+// -- Windows Search/Spotlight logging options
+//@line 464 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
+
+// Whether to use a panel that looks like an OS X sheet for customization
+//@line 469 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
+pref("toolbar.customization.usesheet", false);
+//@line 471 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
+
+// Check for missing attachments?
+pref("mail.compose.attachment_reminder", true);
+// Words that should trigger a missing attachments warning.
+pref("mail.compose.attachment_reminder_keywords", "chrome://messenger/locale/messengercompose/composeMsgs.properties");
+// When no action is taken on the inline missing attachement notification,
+// show an alert on send?
+pref("mail.compose.attachment_reminder_aggressive", true);
+
+pref("browser.formfill.enable", true);
+//@line 482 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
+// Override the all.js values so that unit tests pass and we get sane values.
+pref("browser.formfill.expire_days", 180);
+pref("browser.history_expire_days", 180);
+pref("browser.history_expire_days_min", 90);
+pref("browser.history_expire_sites", 40000);
+//@line 488 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
+
+// Disable autoplay as we don't handle audio elements in emails very well.
+// See bug 515082.
+pref("media.autoplay.enabled", false);
+
+// whether to hide the timeline view by default in the faceted search display
+pref("gloda.facetview.hidetimeline", true);
+
+// Enable gloda by default!
+pref("mailnews.database.global.indexer.enabled", true);
+// Show gloda errors in the error console
+pref("mailnews.database.global.logging.console", true);
+
+// page to load to find good header add-ons
+pref("mailnews.migration.header_addons_url","http://live.mozillamessaging.com/%APP%/addons/search?q=header&locale=%LOCALE%&lver=%VERSION%&hver=%VERSION%&os=%OS%");
+
+// Serif fonts look dated.  Switching those language families to sans-serif
+// where we think it makes sense.  Worth investigating for other font families
+// as well, viz bug 520824.  See all.js for the rest of the font families
+// preferences.
+pref("font.default", "sans-serif");
+pref("font.default.x-unicode", "sans-serif");
+pref("font.default.x-western", "sans-serif");
+
+//@line 527 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
+
+// Since different versions of Windows need different settings, we'll handle
+// this in mailMigrator.js.
+
+// Linux, in other words.  Other OSes may wish to override.
+//@line 533 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
+// The font.name-list fallback is defined in case font.name isn't
+// present -- e.g. in case a profile that's been used on Windows Vista or above
+// is used on Linux.
+pref("font.name-list.serif.x-unicode", "serif");
+pref("font.name-list.sans-serif.x-unicode", "sans-serif");
+pref("font.name-list.monospace.x-unicode", "monospace");
+
+pref("font.name-list.serif.x-western", "serif");
+pref("font.name-list.sans-serif.x-western", "sans-serif");
+pref("font.name-list.monospace.x-western", "monospace");
+//@line 544 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
+
+pref("mail.font.windows.version", 0);
+
+// What level of warning should we send to the error console?
+pref("mail.wizard.logging.console", "None");
+// What level of warning should we send to stdout via dump?
+pref("mail.wizard.logging.dump", "None");
+
+// Handle links targeting new windows (from within content tabs)
+// These are the values that Firefox can be set to:
+// 0=default window, 1=current window/tab, 2=new window,
+// 3=new tab in most recent window
+//
+// Thunderbird only supports a value of 3. Other values can be set, but are
+// not implemented or supported.
+pref("browser.link.open_newwindow", 3);
+
+// These are the values that Firefox can be set to:
+// 0: no restrictions - divert everything
+// 1: don't divert window.open at all
+// 2: don't divert window.open with features
+//
+// Thunderbird only supports a value of 0. Other values can be set, but are
+// not implemented or supported.
+pref("browser.link.open_newwindow.restriction", 0);
+
+pref("browser.tabs.loadDivertedInBackground", false);
