@@ -1,6 +1,6 @@
-//@line 38 "/usr/obj/i386/mozilla-thunderbird-2.0.0.23p1/mozilla/toolkit/components/console/content/console.js"
+//@line 39 "/usr/obj/ports/mozilla-thunderbird-3.1.1/comm-1.9.2/mozilla/toolkit/components/console/content/console.js"
 
-var gConsole, gConsoleBundle, gTextBoxEval;
+var gConsole, gConsoleBundle, gTextBoxEval, gEvaluator, gCodeToEvaluate;
 
 /* :::::::: Console Initialization ::::::::::::::: */
 
@@ -9,12 +9,12 @@ window.onload = function()
   gConsole = document.getElementById("ConsoleBox");
   gConsoleBundle = document.getElementById("ConsoleBundle");
   gTextBoxEval = document.getElementById("TextboxEval")  
+  gEvaluator = document.getElementById("Evaluator");
   
   updateSortCommand(gConsole.sortOrder);
   updateModeCommand(gConsole.mode);
 
-  var iframe = document.getElementById("Evaluator");
-  iframe.addEventListener("load", displayResult, true);
+  gEvaluator.addEventListener("load", loadOrDisplayResult, true);
 }
 
 /* :::::::: Console UI Functions ::::::::::::::: */
@@ -57,25 +57,13 @@ function updateSortCommand(aOrder)
 
 function updateModeCommand(aMode)
 {
-  var bc = document.getElementById("Console:mode" + aMode);
+  /* aMode can end up invalid if it set by an extension that replaces */
+  /* mode and then it is uninstalled or disabled */
+  var bc = document.getElementById("Console:mode" + aMode) ||
+           document.getElementById("Console:modeAll");
   bc.setAttribute("checked", true);
 }
 
-function copyItemToClipboard()
-{
-  gConsole.copySelectedItem();
-}
-
-function isItemSelected()
-{
-  return gConsole.selectedItem != null;
-}
-
-function updateCopyMenu()
-{
-  goSetCommandEnabled("cmd_copy", isItemSelected())
-}
-
 function onEvalKeyPress(aEvent)
 {
   if (aEvent.keyCode == 13)
@@ -84,21 +72,27 @@ function onEvalKeyPress(aEvent)
 
 function evaluateTypein()
 {
-  var code = gTextBoxEval.value;
-  var iframe = document.getElementById("Evaluator");
-  iframe.setAttribute("src", "javascript: " + code);
+  gCodeToEvaluate = gTextBoxEval.value;
+  // reset the iframe first; the code will be evaluated in loadOrDisplayResult
+  // below, once about:blank has completed loading (see bug 385092)
+  gEvaluator.contentWindow.location = "about:blank";
 }
 
-function displayResult()
+function loadOrDisplayResult()
 {
-  var resultRange = Evaluator.document.createRange();
-  resultRange.selectNode(Evaluator.document.documentElement);
+  if (gCodeToEvaluate) {
+    gEvaluator.contentWindow.location = "javascript: " +
+                                        gCodeToEvaluate.replace(/%/g, "%25");
+    gCodeToEvaluate = "";
+    return;
+  }
+
+  var resultRange = gEvaluator.contentDocument.createRange();
+  resultRange.selectNode(gEvaluator.contentDocument.documentElement);
   var result = resultRange.toString();
   if (result)
     gConsole.mCService.logStringMessage(result);
     // or could use appendMessage which doesn't persist
-  var iframe = document.getElementById("Evaluator");
-  iframe.setAttribute("src", "chrome://global/content/blank.html");
 }
 
 // XXX DEBUG
