@@ -1,119 +1,106 @@
-//@line 40 "/usr/obj/i386/mozilla-thunderbird-2.0.0.23p1/mozilla/mail/base/content/customizeToolbar.js"
+//@line 40 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mozilla/toolkit/content/customizeToolbar.js"
 
 const kRowMax = 4;
-const kWindowWidth = 600;
-const kWindowHeight = 400;
-const kAnimateIncrement = 50;
-const kAnimateSteps = kWindowHeight / kAnimateIncrement - 1;
-const kVSizeSlop = 5;
 
 var gToolboxDocument = null;
 var gToolbox = null;
 var gCurrentDragOverItem = null;
 var gToolboxChanged = false;
-var gPreviousMode = null;
-var gPreviousIconSize = null;
+var gToolboxIconSize = false;
+var gToolboxSheet = false;
 
 function onLoad()
 {
-  gToolbox = window.arguments[0];
+  if ("arguments" in window && window.arguments[0]) {
+    InitWithToolbox(window.arguments[0]);
+    repositionDialog();
+  }
+  else if (window.frameElement &&
+           "toolbox" in window.frameElement) {
+    gToolboxSheet = true;
+    InitWithToolbox(window.frameElement.toolbox);
+  }
+}
+
+function InitWithToolbox(aToolbox)
+{
+  gToolbox = aToolbox;
   gToolboxDocument = gToolbox.ownerDocument;
-  
-  gToolbox.addEventListener("draggesture", onToolbarDragGesture, false);
+  gToolbox.customizing = true;
+
+  gToolbox.addEventListener("dragstart", onToolbarDragStart, false);
   gToolbox.addEventListener("dragover", onToolbarDragOver, false);
-  gToolbox.addEventListener("dragexit", onToolbarDragExit, false);
-  gToolbox.addEventListener("dragdrop", onToolbarDragDrop, false);
-  repositionDialog();
+  gToolbox.addEventListener("dragleave", onToolbarDragLeave, false);
+  gToolbox.addEventListener("drop", onToolbarDrop, false);
 
   initDialog();
+
+  notifyParentInitialized();
 }
 
-function onUnload(aEvent)
+function onClose()
+{
+  if (!gToolboxSheet)
+    window.close();
+  else
+    finishToolbarCustomization();
+}
+
+function onUnload()
+{
+  if (!gToolboxSheet)
+    finishToolbarCustomization();
+}
+
+function finishToolbarCustomization()
 {
   removeToolboxListeners();
-  unwrapToolbarItems(true);
+  unwrapToolbarItems();
   persistCurrentSets();
-  
+  gToolbox.customizing = false;
+
   notifyParentComplete();
 }
 
-function onCancel()
-{
-  // restore the saved toolbarset for each customizeable toolbar
-  unwrapToolbarItems(false);
-  var toolbar = gToolbox.firstChild;
-  while (toolbar) {
-    if (isCustomizableToolbar(toolbar)) {
-      if (!toolbar.hasAttribute("customindex")) {
-        var previousset = toolbar.getAttribute("previousset");
-        if (previousset)
-        {
-          toolbar.currentSet = previousset;
-        }
-      }
-    }
-    toolbar = toolbar.nextSibling;
-  }
-
-  // restore the previous mode and iconsize
-  updateIconSize(gPreviousIconSize == "small");
-  updateToolbarMode(gPreviousMode);
-
-  repositionDialog();
-  gToolboxChanged = true;
-
-  return onAccept(); // we restored the default toolbar, act like a normal accept event now
-}
-
-function onAccept(aEvent)
-{
-  document.getElementById("main-box").collapsed = true;
-  window.close();
-}
-
 function initDialog()
 {
-  document.getElementById("main-box").collapsed = false;
-  
-  gPreviousMode = gToolbox.getAttribute("mode");
-  document.getElementById("modelist").value = gPreviousMode;
-  gPreviousIconSize = gToolbox.getAttribute("iconsize");
+  var mode = gToolbox.getAttribute("mode");
+  document.getElementById("modelist").value = mode;
+  gToolboxIconSize = gToolbox.getAttribute("iconsize");
   var smallIconsCheckbox = document.getElementById("smallicons");
-  if (gPreviousMode == "text")
+  smallIconsCheckbox.checked = gToolboxIconSize == "small";
+  if (mode == "text")
     smallIconsCheckbox.disabled = true;
-  else
-    smallIconsCheckbox.checked = gPreviousIconSize == "small";
 
   // Build up the palette of other items.
   buildPalette();
 
   // Wrap all the items on the toolbar in toolbarpaletteitems.
-  wrapToolbarItems(true);
+  wrapToolbarItems();
 }
 
 function repositionDialog()
 {
-  // Position the dialog touching the bottom of the toolbox and centered with 
-  // it. We must resize the window smaller first so that it is positioned 
-  // properly. 
-  var screenX = gToolbox.boxObject.screenX + ((gToolbox.boxObject.width - kWindowWidth) / 2);
+  // Position the dialog touching the bottom of the toolbox and centered with
+  // it.
+  var width;
+  if (document.documentElement.hasAttribute("width"))
+    width = document.documentElement.getAttribute("width");
+  else
+    width = parseInt(document.documentElement.style.width);
+  var screenX = gToolbox.boxObject.screenX
+                + ((gToolbox.boxObject.width - width) / 2);
   var screenY = gToolbox.boxObject.screenY + gToolbox.boxObject.height;
 
-  var newHeight = kWindowHeight;
-  if (newHeight >= screen.availHeight - screenY - kVSizeSlop) {
-    newHeight = screen.availHeight - screenY - kVSizeSlop;
-  }
-
-  window.resizeTo(kWindowWidth, newHeight);
   window.moveTo(screenX, screenY);
 }
 
 function removeToolboxListeners()
 {
-  gToolbox.removeEventListener("draggesture", onToolbarDragGesture, false);
+  gToolbox.removeEventListener("dragstart", onToolbarDragStart, false);
   gToolbox.removeEventListener("dragover", onToolbarDragOver, false);
-  gToolbox.removeEventListener("dragexit", onToolbarDragExit, false);
-  gToolbox.removeEventListener("dragdrop", onToolbarDragDrop, false);
+  gToolbox.removeEventListener("dragleave", onToolbarDragLeave, false);
+  gToolbox.removeEventListener("drop", onToolbarDrop, false);
 }
 
 /**
@@ -126,6 +113,23 @@ function notifyParentComplete()
     gToolbox.customizeDone(gToolboxChanged);
 }
 
+/**
+ * Invoke a callback on the toolbox to notify it that the dialog is fully
+ * initialized.
+ */
+function notifyParentInitialized()
+{
+  if ("customizeInitialized" in gToolbox)
+    gToolbox.customizeInitialized();
+}
+
+function toolboxChanged(aEvent)
+{
+  gToolboxChanged = true;
+  if ("customizeChange" in gToolbox)
+    gToolbox.customizeChange(aEvent);
+}
+
 function getToolbarAt(i)
 {
   return gToolbox.childNodes[i];
@@ -137,7 +141,7 @@ function getToolbarAt(i)
  */
 function persistCurrentSets()
 {
-  if (!gToolboxChanged)
+  if (!gToolboxChanged || gToolboxDocument.defaultView.closed)
     return;
 
   var customCount = 0;
@@ -148,7 +152,7 @@ function persistCurrentSets()
       // Calculate currentset and store it in the attribute.
       var currentSet = toolbar.currentSet;
       toolbar.setAttribute("currentset", currentSet);
-      
+
       var customIndex = toolbar.hasAttribute("customindex");
       if (customIndex) {
         if (!toolbar.firstChild) {
@@ -169,7 +173,7 @@ function persistCurrentSets()
       }
     }
   }
-  
+
   // Remove toolbarX attributes for removed toolbars.
   while (gToolbox.toolbarset.hasAttribute("toolbar"+(++customCount))) {
     gToolbox.toolbarset.removeAttribute("toolbar"+customCount);
@@ -180,24 +184,19 @@ function persistCurrentSets()
 /**
  * Wraps all items in all customizable toolbars in a toolbox.
  */
-function wrapToolbarItems(aStorePreviousSet)
+function wrapToolbarItems()
 {
   for (var i = 0; i < gToolbox.childNodes.length; ++i) {
     var toolbar = getToolbarAt(i);
     if (isCustomizableToolbar(toolbar)) {
-      if (aStorePreviousSet)
-        toolbar.setAttribute('previousset', toolbar.currentSet);
-
       for (var k = 0; k < toolbar.childNodes.length; ++k) {
         var item = toolbar.childNodes[k];
+
+//@line 237 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mozilla/toolkit/content/customizeToolbar.js"
+
         if (isToolbarItem(item)) {
-          var nextSibling = item.nextSibling;
-          
-          var wrapper = wrapToolbarItem(item);     
-          if (nextSibling)
-            toolbar.insertBefore(wrapper, nextSibling);
-          else
-            toolbar.appendChild(wrapper);
+          var wrapper = wrapToolbarItem(item);
+          cleanupItemForToolbar(item, wrapper);
         }
       }
     }
@@ -207,50 +206,38 @@ function wrapToolbarItems(aStorePreviousSet)
 /**
  * Unwraps all items in all customizable toolbars in a toolbox.
  */
- function unwrapToolbarItems(aRemovePreviousSet)
+function unwrapToolbarItems()
 {
-  for (var i = 0; i < gToolbox.childNodes.length; ++i) {
-    var toolbar = getToolbarAt(i);
-    if (isCustomizableToolbar(toolbar)) {
-      if (aRemovePreviousSet)
-        toolbar.removeAttribute('previousset');
+  var paletteItems = gToolbox.getElementsByTagName("toolbarpaletteitem");
+  var paletteItem;
+  while ((paletteItem = paletteItems.item(0)) != null) {
+    var toolbarItem = paletteItem.firstChild;
 
-      for (var k = 0; k < toolbar.childNodes.length; ++k) {
-        var paletteItem = toolbar.childNodes[k];
-        var toolbarItem = paletteItem.firstChild;
+    if (paletteItem.hasAttribute("itemdisabled"))
+      toolbarItem.disabled = true;
 
-        if (toolbarItem && isToolbarItem(toolbarItem)) {
-          var nextSibling = paletteItem.nextSibling;
+    if (paletteItem.hasAttribute("itemcommand")) {
+      let commandID = paletteItem.getAttribute("itemcommand");
+      toolbarItem.setAttribute("command", commandID);
 
-          if (paletteItem.hasAttribute("itemcommand"))
-            toolbarItem.setAttribute("command", paletteItem.getAttribute("itemcommand"));
-          if (paletteItem.hasAttribute("itemobserves"))
-            toolbarItem.setAttribute("observes", paletteItem.getAttribute("itemobserves"));
-
-          paletteItem.removeChild(toolbarItem); 
-          paletteItem.parentNode.removeChild(paletteItem);
-
-          if (nextSibling)
-            toolbar.insertBefore(toolbarItem, nextSibling);
-          else
-            toolbar.appendChild(toolbarItem);
-        }
-      }
+      //XXX Bug 309953 - toolbarbuttons aren't in sync with their commands after customizing
+      toolbarItem.disabled = gToolboxDocument.getElementById(commandID).disabled;
     }
+
+    paletteItem.parentNode.replaceChild(toolbarItem, paletteItem);
   }
 }
 
-
 /**
  * Creates a wrapper that can be used to contain a toolbaritem and prevent
  * it from receiving UI events.
  */
-function createWrapper(aId)
+function createWrapper(aId, aDocument)
 {
-  var wrapper = document.createElementNS("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul",
+  var wrapper = aDocument.createElementNS("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul",
                                          "toolbarpaletteitem");
 
-  wrapper.id = "wrapper-"+aId;  
+  wrapper.id = "wrapper-"+aId;
   return wrapper;
 }
 
@@ -260,7 +247,7 @@ function createWrapper(aId)
  */
 function wrapPaletteItem(aPaletteItem, aCurrentRow, aSpacer)
 {
-  var wrapper = createWrapper(aPaletteItem.id);
+  var wrapper = createWrapper(aPaletteItem.id, document);
 
   wrapper.setAttribute("flex", 1);
   wrapper.setAttribute("align", "center");
@@ -269,9 +256,9 @@ function wrapPaletteItem(aPaletteItem, aCurrentRow, aSpacer)
   wrapper.setAttribute("minwidth", "0");
 
   wrapper.appendChild(aPaletteItem);
-  
+
   // XXX We need to call this AFTER the palette item has been appended
-  // to the wrapper or else we crash dropping certain buttons on the 
+  // to the wrapper or else we crash dropping certain buttons on the
   // palette due to removal of the command and disabled attributes - JRH
   cleanUpItemForPalette(aPaletteItem, wrapper);
 
@@ -289,16 +276,14 @@ function wrapPaletteItem(aPaletteItem, aCurrentRow, aSpacer)
  */
 function wrapToolbarItem(aToolbarItem)
 {
-  var wrapper = createWrapper(aToolbarItem.id);
-  
-  cleanupItemForToolbar(aToolbarItem, wrapper);
+  var wrapper = createWrapper(aToolbarItem.id, gToolboxDocument);
+
   wrapper.flex = aToolbarItem.flex;
 
-  if (aToolbarItem.parentNode)
-    aToolbarItem.parentNode.removeChild(aToolbarItem);
-  
+  aToolbarItem.parentNode.replaceChild(wrapper, aToolbarItem);
+
   wrapper.appendChild(aToolbarItem);
-  
+
   return wrapper;
 }
 
@@ -363,7 +348,7 @@ function buildPalette()
   while (templateNode) {
     // Check if the item is already in a toolbar before adding it to the palette.
     if (!(templateNode.id in currentItems)) {
-      var paletteItem = templateNode.cloneNode(true);
+      var paletteItem = document.importNode(templateNode, true);
 
       if (rowSlot == kRowMax) {
         // Append the old row.
@@ -379,11 +364,11 @@ function buildPalette()
       ++rowSlot;
       wrapPaletteItem(paletteItem, currentRow, null);
     }
-    
+
     templateNode = templateNode.nextSibling;
   }
 
-  if (currentRow) { 
+  if (currentRow) {
     fillRowWithFlex(currentRow);
     paletteBox.appendChild(currentRow);
   }
@@ -398,14 +383,14 @@ function appendPaletteItem(aItem)
   var paletteBox = document.getElementById("palette-box");
   var lastRow = paletteBox.lastChild;
   var lastSpacer = lastRow.lastChild;
-   
+
   if (lastSpacer.localName != "spacer") {
     // The current row is full, so we have to create a new row.
     lastRow = document.createElementNS("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul",
                                         "hbox");
     lastRow.setAttribute("class", "paletteRow");
     paletteBox.appendChild(lastRow);
-    
+
     wrapPaletteItem(aItem, lastRow, null);
 
     fillRowWithFlex(lastRow);
@@ -436,7 +421,7 @@ function fillRowWithFlex(aRow)
 
 /**
  * Makes sure that an item that has been cloned from a template
- * is stripped of all properties that may adversely affect it's
+ * is stripped of any attributes that may adversely affect its
  * appearance in the palette.
  */
 function cleanUpItemForPalette(aItem, aWrapper)
@@ -448,19 +433,22 @@ function cleanUpItemForPalette(aItem, aWrapper)
     aWrapper.setAttribute("title", aItem.getAttribute("title"));
   else if (isSpecialItem(aItem)) {
     var stringBundle = document.getElementById("stringBundle");
-    var title = stringBundle.getString(aItem.id + "Title");
+    // Remove the common "toolbar" prefix to generate the string name.
+    var title = stringBundle.getString(aItem.localName.slice(7) + "Title");
     aWrapper.setAttribute("title", title);
   }
-  
+
   // Remove attributes that screw up our appearance.
   aItem.removeAttribute("command");
   aItem.removeAttribute("observes");
-  aItem.removeAttribute("disabled");
   aItem.removeAttribute("type");
-  
-  if (aItem.localName == "toolbaritem" && aItem.firstChild) {
-    aItem.firstChild.removeAttribute("observes");
+  aItem.removeAttribute("width");
 
+  Array.forEach(aWrapper.querySelectorAll("[disabled]"), function(aNode) {
+    aNode.removeAttribute("disabled");
+  });
+
+  if (aItem.localName == "toolbaritem" && aItem.firstChild) {
     // So the throbber doesn't throb in the dialog,
     // cute as that may be...
     aItem.firstChild.removeAttribute("busy");
@@ -469,8 +457,8 @@ function cleanUpItemForPalette(aItem, aWrapper)
 
 /**
  * Makes sure that an item that has been cloned from a template
- * is stripped of all properties that may adversely affect it's
- * appearance in the toolbar.  Store critical properties on the 
+ * is stripped of all properties that may adversely affect its
+ * appearance in the toolbar.  Store critical properties on the
  * wrapper so they can be put back on the item when we're done.
  */
 function cleanupItemForToolbar(aItem, aWrapper)
@@ -483,12 +471,6 @@ function cleanupItemForToolbar(aItem, aWrapper)
     aItem.removeAttribute("command");
   }
 
-  if (aItem.hasAttribute("observes"))
-  {
-    aWrapper.setAttribute("itemobserves", aItem.getAttribute("observes"));
-    aItem.removeAttribute("observes");
-  }
-
   if (aItem.disabled) {
     aWrapper.setAttribute("itemdisabled", "true");
     aItem.disabled = false;
@@ -517,10 +499,10 @@ function setDragActive(aItem, aValue)
     node = aItem.lastChild;
     value = direction == "ltr"? "right" : "left";
   }
-  
+
   if (!node)
     return;
-  
+
   if (aValue) {
     if (!node.hasAttribute("dragover"))
       node.setAttribute("dragover", value);
@@ -529,6 +511,62 @@ function setDragActive(aItem, aValue)
   }
 }
 
+function addNewToolbar()
+{
+  var promptService = Components.classes["@mozilla.org/embedcomp/prompt-service;1"]
+                                .getService(Components.interfaces.nsIPromptService);
+
+  var stringBundle = document.getElementById("stringBundle");
+  var message = stringBundle.getString("enterToolbarName");
+  var title = stringBundle.getString("enterToolbarTitle");
+
+  var name = {};
+
+  // Quitting from the toolbar dialog while the new toolbar prompt is up
+  // can cause things to become unresponsive on the Mac. Until dialog modality
+  // is fixed (395465), disable the "Done" button explicitly.
+  var doneButton = document.getElementById("donebutton");
+  doneButton.disabled = true;
+
+  while (true) {
+
+    if (!promptService.prompt(window, title, message, name, null, {})) {
+      doneButton.disabled = false;
+      return;
+    }
+
+    if (!name.value) {
+      message = stringBundle.getFormattedString("enterToolbarBlank", [name.value]);
+      continue;
+    }
+
+    var dupeFound = false;
+
+     // Check for an existing toolbar with the same display name
+    for (i = 0; i < gToolbox.childNodes.length; ++i) {
+      var toolbar = gToolbox.childNodes[i];
+      var toolbarName = toolbar.getAttribute("toolbarname");
+
+      if (toolbarName == name.value &&
+          toolbar.getAttribute("type") != "menubar" &&
+          toolbar.nodeName == 'toolbar') {
+        dupeFound = true;
+        break;
+      }
+    }
+
+    if (!dupeFound)
+      break;
+
+    message = stringBundle.getFormattedString("enterToolbarDup", [name.value]);
+  }
+
+  gToolbox.appendCustomToolbar(name.value, "");
+
+  toolboxChanged();
+
+  doneButton.disabled = false;
+}
 
 /**
  * Restore the default set of buttons to fixed toolbars,
@@ -536,27 +574,8 @@ function setDragActive(aItem, aValue)
  */
 function restoreDefaultSet()
 {
-  // Restore the defaultset for fixed toolbars.
-  unwrapToolbarItems(false);
-  var toolbar = gToolbox.firstChild;
-  while (toolbar) {
-    if (isCustomizableToolbar(toolbar)) {
-      if (!toolbar.hasAttribute("customindex")) {
-        var defaultSet = toolbar.getAttribute("defaultset");
-        if (defaultSet)
-        {
-          toolbar.currentSet = defaultSet;
-        }
-      }
-    }
-    toolbar = toolbar.nextSibling;
-  }
-
-  // Restore the default icon size (large) and mode (icons and text).
-  updateIconSize(false);
-  document.getElementById("smallicons").checked = false;
-  updateToolbarMode("full");
-  document.getElementById("modelist").value = "full";
+  // Unwrap the items on the toolbar.
+  unwrapToolbarItems();
 
   // Remove all of the customized toolbars.
   var child = gToolbox.lastChild;
@@ -564,41 +583,62 @@ function restoreDefaultSet()
     if (child.hasAttribute("customindex")) {
       var thisChild = child;
       child = child.previousSibling;
+      thisChild.currentSet = "__empty";
       gToolbox.removeChild(thisChild);
     } else {
       child = child.previousSibling;
     }
   }
-  
+
+  // Restore the defaultset for fixed toolbars.
+  var toolbar = gToolbox.firstChild;
+  while (toolbar) {
+    if (isCustomizableToolbar(toolbar)) {
+      var defaultSet = toolbar.getAttribute("defaultset");
+      if (defaultSet)
+        toolbar.currentSet = defaultSet;
+    }
+    toolbar = toolbar.nextSibling;
+  }
+
+  // Restore the default icon size and mode.
+  var defaultMode = gToolbox.getAttribute("defaultmode");
+  var defaultIconsSmall = gToolbox.getAttribute("defaulticonsize") == "small";
+
+  updateIconSize(defaultIconsSmall, true);
+  document.getElementById("smallicons").checked = defaultIconsSmall;
+  updateToolbarMode(defaultMode, true);
+  document.getElementById("modelist").value = defaultMode;
+
   // Now rebuild the palette.
   buildPalette();
 
-  // Now re-wrap the items on the toolbar, but don't clobber previousset.
-  wrapToolbarItems(false);
+  // Now re-wrap the items on the toolbar.
+  wrapToolbarItems();
 
-  repositionDialog();
-  gToolboxChanged = true;
+  toolboxChanged("reset");
 }
 
-function updateIconSize(aUseSmallIcons)
+function updateIconSize(aUseSmallIcons, localDefault)
 {
-  var val = aUseSmallIcons ? "small" : null;
-  
-  setAttribute(gToolbox, "iconsize", val);
+  gToolboxIconSize = aUseSmallIcons ? "small" : "large";
+
+  setAttribute(gToolbox, "iconsize", gToolboxIconSize);
   gToolboxDocument.persist(gToolbox.id, "iconsize");
-  
+
   for (var i = 0; i < gToolbox.childNodes.length; ++i) {
     var toolbar = getToolbarAt(i);
     if (isCustomizableToolbar(toolbar)) {
-      setAttribute(toolbar, "iconsize", val);
+      var toolbarIconSize = (localDefault && toolbar.hasAttribute("defaulticonsize")) ?
+                            toolbar.getAttribute("defaulticonsize") :
+                            gToolboxIconSize;
+      setAttribute(toolbar, "iconsize", toolbarIconSize);
       gToolboxDocument.persist(toolbar.id, "iconsize");
     }
   }
-
-  repositionDialog();
 }
 
-function updateToolbarMode(aModeValue)
+function updateToolbarMode(aModeValue, localDefault)
 {
   setAttribute(gToolbox, "mode", aModeValue);
   gToolboxDocument.persist(gToolbox.id, "mode");
@@ -606,15 +646,16 @@ function updateToolbarMode(aModeValue)
   for (var i = 0; i < gToolbox.childNodes.length; ++i) {
     var toolbar = getToolbarAt(i);
     if (isCustomizableToolbar(toolbar)) {
-      setAttribute(toolbar, "mode", aModeValue);
+      var toolbarMode = (localDefault && toolbar.hasAttribute("defaultmode")) ?
+                        toolbar.getAttribute("defaultmode") :
+                        aModeValue;
+      setAttribute(toolbar, "mode", toolbarMode);
       gToolboxDocument.persist(toolbar.id, "mode");
     }
   }
 
   var iconSizeCheckbox = document.getElementById("smallicons");
   iconSizeCheckbox.disabled = aModeValue == "text";
-
-  repositionDialog();
 }
 
 
@@ -651,271 +692,219 @@ function isToolbarItem(aElt)
 ///////////////////////////////////////////////////////////////////////////
 //// Drag and Drop observers
 
-function onToolbarDragGesture(aEvent)
-{
-  nsDragAndDrop.startDrag(aEvent, dragStartObserver);
-}
-
-function onToolbarDragOver(aEvent)
-{
-  nsDragAndDrop.dragOver(aEvent, toolbarDNDObserver);
-}
-
-function onToolbarDragDrop(aEvent)
-{
-  nsDragAndDrop.drop(aEvent, toolbarDNDObserver);
-}
-
-function onToolbarDragExit(aEvent)
+function onToolbarDragLeave(aEvent)
 {
   if (gCurrentDragOverItem)
     setDragActive(gCurrentDragOverItem, false);
 }
 
-var dragStartObserver =
+function onToolbarDragStart(aEvent)
 {
-  onDragStart: function (aEvent, aXferData, aDragAction) {
-    var documentId = gToolboxDocument.documentElement.id;
-    
-    var item = aEvent.target;
-    while (item && item.localName != "toolbarpaletteitem")
-      item = item.parentNode;
-    
-    item.setAttribute("dragactive", "true");
-    
-    aXferData.data = new TransferDataSet();
-    var data = new TransferData();
-    data.addDataForFlavour("text/toolbarwrapper-id/"+documentId, item.firstChild.id);
-    aXferData.data.push(data);
-  }
+  var documentId = gToolboxDocument.documentElement.id;
+
+  var item = aEvent.target;
+  while (item && item.localName != "toolbarpaletteitem")
+    item = item.parentNode;
+
+  item.setAttribute("dragactive", "true");
+
+  var dt = aEvent.dataTransfer;
+  dt.setData("text/toolbarwrapper-id/" + documentId, item.firstChild.id);
+  dt.effectAllowed = "move";
 }
 
-var toolbarDNDObserver =
+function onToolbarDragOver(aEvent)
 {
-  onDragOver: function (aEvent, aFlavour, aDragSession)
-  {
-    var toolbar = aEvent.target;
-    var dropTarget = aEvent.target;
-    while (toolbar && toolbar.localName != "toolbar") {
-      dropTarget = toolbar;
-      toolbar = toolbar.parentNode;
-    }
-    
-    var previousDragItem = gCurrentDragOverItem;
+  var documentId = gToolboxDocument.documentElement.id;
+  if (!aEvent.dataTransfer.types.contains("text/toolbarwrapper-id/" + documentId))
+    return;
 
-    // Make sure we are dragging over a customizable toolbar.
-    if (!isCustomizableToolbar(toolbar)) {
-      gCurrentDragOverItem = null;
-      return;
-    }
-    
-    if (dropTarget.localName == "toolbar") {
-      gCurrentDragOverItem = dropTarget;
-    } else {
-      gCurrentDragOverItem = null;
+  var toolbar = aEvent.target;
+  var dropTarget = aEvent.target;
+  while (toolbar && toolbar.localName != "toolbar") {
+    dropTarget = toolbar;
+    toolbar = toolbar.parentNode;
+  }
 
-      var direction = window.getComputedStyle(dropTarget.parentNode, null).direction;
-      var dropTargetCenter = dropTarget.boxObject.x + (dropTarget.boxObject.width / 2);
-      if (direction == "ltr")
-        dragAfter = aEvent.clientX > dropTargetCenter;
-      else
-        dragAfter = aEvent.clientX < dropTargetCenter;
-        
-      if (dragAfter) {
-        gCurrentDragOverItem = dropTarget.nextSibling;
-        if (!gCurrentDragOverItem)
-          gCurrentDragOverItem = toolbar;
-      } else
-        gCurrentDragOverItem = dropTarget;
-    }    
+  var previousDragItem = gCurrentDragOverItem;
 
-    if (previousDragItem && gCurrentDragOverItem != previousDragItem) {
-      setDragActive(previousDragItem, false);
-    }
-    
-    setDragActive(gCurrentDragOverItem, true);
-    
-    aDragSession.canDrop = true;
-  },
-  
-  onDrop: function (aEvent, aXferData, aDragSession)
-  {
-    if (!gCurrentDragOverItem)
-      return;
-    
-    setDragActive(gCurrentDragOverItem, false);
+  // Make sure we are dragging over a customizable toolbar.
+  if (!isCustomizableToolbar(toolbar)) {
+    gCurrentDragOverItem = null;
+    return;
+  }
 
-    var draggedItemId = aXferData.data;
-    if (gCurrentDragOverItem.id == draggedItemId)
-      return;
-
-    var toolbar = aEvent.target;
-    while (toolbar.localName != "toolbar")
-      toolbar = toolbar.parentNode;
-
-    var draggedPaletteWrapper = document.getElementById("wrapper-"+draggedItemId);       
-    if (!draggedPaletteWrapper) {
-      // The wrapper has been dragged from the toolbar.
-      
-      // Get the wrapper from the toolbar document and make sure that
-      // it isn't being dropped on itself.
-      var wrapper = gToolboxDocument.getElementById("wrapper-"+draggedItemId);
-      if (wrapper == gCurrentDragOverItem)
-        return;
-
-      // Don't allow static kids (e.g., the menubar) to move.
-      if (wrapper.parentNode.firstPermanentChild && wrapper.parentNode.firstPermanentChild.id == wrapper.firstChild.id)
-        return;
-      if (wrapper.parentNode.lastPermanentChild && wrapper.parentNode.lastPermanentChild.id == wrapper.firstChild.id)
-        return;
-
-      // Remove the item from it's place in the toolbar.
-      wrapper.parentNode.removeChild(wrapper);
-
-      // Determine which toolbar we are dropping on.
-      var dropToolbar = null;
-      if (gCurrentDragOverItem.localName == "toolbar")
-        dropToolbar = gCurrentDragOverItem;
-      else
-        dropToolbar = gCurrentDragOverItem.parentNode;
-      
-      // Insert the item into the toolbar.
-      if (gCurrentDragOverItem != dropToolbar)
-        dropToolbar.insertBefore(wrapper, gCurrentDragOverItem);
-      else
-        dropToolbar.appendChild(wrapper);
-    } else {
-      // The item has been dragged from the palette
-      
-      // Create a new wrapper for the item. We don't know the id yet.
-      var wrapper = createWrapper("");
-
-      // Ask the toolbar to clone the item's template, place it inside the wrapper, and insert it in the toolbar.
-      var newItem = toolbar.insertItem(draggedItemId, gCurrentDragOverItem == toolbar ? null : gCurrentDragOverItem, wrapper);
-      
-      // Prepare the item and wrapper to look good on the toolbar.
-      cleanupItemForToolbar(newItem, wrapper);
-      wrapper.id = "wrapper-"+newItem.id;
-      wrapper.flex = newItem.flex;
-
-      // Remove the wrapper from the palette.
-      var currentRow = draggedPaletteWrapper.parentNode;
-      if (draggedItemId != "separator" &&
-          draggedItemId != "spring" &&
-          draggedItemId != "spacer")
-      {
-        currentRow.removeChild(draggedPaletteWrapper);
-
-        while (currentRow) {
-          // Pull the first child of the next row up
-          // into this row.
-          var nextRow = currentRow.nextSibling;
-          
-          if (!nextRow) {
-            var last = currentRow.lastChild;
-            var first = currentRow.firstChild;
-            if (first == last) {
-              // Kill the row.
-              currentRow.parentNode.removeChild(currentRow);
-              break;
-            }
-
-            if (last.localName == "spacer") {
-              var flex = last.getAttribute("flex");
-              last.setAttribute("flex", ++flex);
-              // Reflow doesn't happen for some reason.  Trigger it with a hide/show. ICK! -dwh
-              last.hidden = true;
-              last.hidden = false;
-              break;
-            } else {
-              // Make a spacer and give it a flex of 1.
-              var spacer = document.createElementNS("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul",
-                                                    "spacer");
-              spacer.setAttribute("flex", "1");
-              currentRow.appendChild(spacer);
-            }
-            break;
-          }
-          
-          currentRow.appendChild(nextRow.firstChild);
-          currentRow = currentRow.nextSibling;
-        }
-      }
-    }
-    
+  if (dropTarget.localName == "toolbar") {
+    gCurrentDragOverItem = dropTarget;
+  } else {
     gCurrentDragOverItem = null;
 
-    repositionDialog();
-    gToolboxChanged = true;
-  },
-  
-  _flavourSet: null,
-  
-  getSupportedFlavours: function ()
-  {
-    if (!this._flavourSet) {
-      this._flavourSet = new FlavourSet();
-      var documentId = gToolboxDocument.documentElement.id;
-      this._flavourSet.appendFlavour("text/toolbarwrapper-id/"+documentId);
-    }
-    return this._flavourSet;
+    var direction = window.getComputedStyle(dropTarget.parentNode, null).direction;
+    var dropTargetCenter = dropTarget.boxObject.x + (dropTarget.boxObject.width / 2);
+    var dragAfter;
+    if (direction == "ltr")
+      dragAfter = aEvent.clientX > dropTargetCenter;
+    else
+      dragAfter = aEvent.clientX < dropTargetCenter;
+
+    if (dragAfter) {
+      gCurrentDragOverItem = dropTarget.nextSibling;
+      if (!gCurrentDragOverItem)
+        gCurrentDragOverItem = toolbar;
+    } else
+      gCurrentDragOverItem = dropTarget;
   }
+
+  if (previousDragItem && gCurrentDragOverItem != previousDragItem) {
+    setDragActive(previousDragItem, false);
+  }
+
+  setDragActive(gCurrentDragOverItem, true);
+
+  aEvent.preventDefault();
 }
 
-var paletteDNDObserver =
+function onToolbarDrop(aEvent)
 {
-  onDragOver: function (aEvent, aFlavour, aDragSession)
-  {
-    aDragSession.canDrop = true;
-  },
-  
-  onDrop: function(aEvent, aXferData, aDragSession)
-  {
-    var itemId = aXferData.data;
-    
-    var wrapper = gToolboxDocument.getElementById("wrapper-"+itemId);
-    if (wrapper) {
-      // Don't allow static kids (e.g., the menubar) to move.
-      if (wrapper.parentNode.firstPermanentChild && wrapper.parentNode.firstPermanentChild.id == wrapper.firstChild.id)
-        return;
-      if (wrapper.parentNode.lastPermanentChild && wrapper.parentNode.lastPermanentChild.id == wrapper.firstChild.id)
-        return;
+  if (!gCurrentDragOverItem)
+    return;
 
-      // The item was dragged out of the toolbar.
-      wrapper.parentNode.removeChild(wrapper);
-      
-      var wrapperType = wrapper.getAttribute("type");
-      if (wrapperType != "separator" && wrapperType != "spacer" && wrapperType != "spring") {
-        // Find the template node in the toolbox palette
-        var templateNode = gToolbox.palette.firstChild;
-        while (templateNode) {
-          if (templateNode.id == itemId)
+  setDragActive(gCurrentDragOverItem, false);
+
+  var documentId = gToolboxDocument.documentElement.id;
+  var draggedItemId = aEvent.dataTransfer.getData("text/toolbarwrapper-id/" + documentId);
+  if (gCurrentDragOverItem.id == draggedItemId)
+    return;
+
+  var toolbar = aEvent.target;
+  while (toolbar.localName != "toolbar")
+    toolbar = toolbar.parentNode;
+
+  var draggedPaletteWrapper = document.getElementById("wrapper-"+draggedItemId);
+  if (!draggedPaletteWrapper) {
+    // The wrapper has been dragged from the toolbar.
+    // Get the wrapper from the toolbar document and make sure that
+    // it isn't being dropped on itself.
+    var wrapper = gToolboxDocument.getElementById("wrapper-"+draggedItemId);
+    if (wrapper == gCurrentDragOverItem)
+       return;
+
+    // Don't allow static kids (e.g., the menubar) to move.
+    if (wrapper.parentNode.firstPermanentChild && wrapper.parentNode.firstPermanentChild.id == wrapper.firstChild.id)
+      return;
+    if (wrapper.parentNode.lastPermanentChild && wrapper.parentNode.lastPermanentChild.id == wrapper.firstChild.id)
+      return;
+
+    // Remove the item from its place in the toolbar.
+    wrapper.parentNode.removeChild(wrapper);
+
+    // Determine which toolbar we are dropping on.
+    var dropToolbar = null;
+    if (gCurrentDragOverItem.localName == "toolbar")
+      dropToolbar = gCurrentDragOverItem;
+    else
+      dropToolbar = gCurrentDragOverItem.parentNode;
+
+    // Insert the item into the toolbar.
+    if (gCurrentDragOverItem != dropToolbar)
+      dropToolbar.insertBefore(wrapper, gCurrentDragOverItem);
+    else
+      dropToolbar.appendChild(wrapper);
+  } else {
+    // The item has been dragged from the palette
+
+    // Create a new wrapper for the item. We don't know the id yet.
+    var wrapper = createWrapper("", gToolboxDocument);
+
+    // Ask the toolbar to clone the item's template, place it inside the wrapper, and insert it in the toolbar.
+    var newItem = toolbar.insertItem(draggedItemId, gCurrentDragOverItem == toolbar ? null : gCurrentDragOverItem, wrapper);
+
+    // Prepare the item and wrapper to look good on the toolbar.
+    cleanupItemForToolbar(newItem, wrapper);
+    wrapper.id = "wrapper-"+newItem.id;
+    wrapper.flex = newItem.flex;
+
+    // Remove the wrapper from the palette.
+    var currentRow = draggedPaletteWrapper.parentNode;
+    if (draggedItemId != "separator" &&
+        draggedItemId != "spring" &&
+        draggedItemId != "spacer")
+    {
+      currentRow.removeChild(draggedPaletteWrapper);
+
+      while (currentRow) {
+        // Pull the first child of the next row up
+        // into this row.
+        var nextRow = currentRow.nextSibling;
+
+        if (!nextRow) {
+          var last = currentRow.lastChild;
+          var first = currentRow.firstChild;
+          if (first == last) {
+            // Kill the row.
+            currentRow.parentNode.removeChild(currentRow);
+             break;
+           }
+
+          if (last.localName == "spacer") {
+            var flex = last.getAttribute("flex");
+            last.setAttribute("flex", ++flex);
+            // Reflow doesn't happen for some reason.  Trigger it with a hide/show. ICK! -dwh
+            last.hidden = true;
+            last.hidden = false;
             break;
-          templateNode = templateNode.nextSibling;
+          } else {
+            // Make a spacer and give it a flex of 1.
+            var spacer = document.createElementNS("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul",
+                                                  "spacer");
+            spacer.setAttribute("flex", "1");
+            currentRow.appendChild(spacer);
+          }
+          break;
         }
-        if (!templateNode)
-          return;
-        
-        // Clone the template and add it to our palette.
-        var paletteItem = templateNode.cloneNode(true);
-        appendPaletteItem(paletteItem);
+
+        currentRow.appendChild(nextRow.firstChild);
+        currentRow = currentRow.nextSibling;
       }
     }
-    
-    repositionDialog();
-    gToolboxChanged = true;
-  },
-  
-  _flavourSet: null,
-  
-  getSupportedFlavours: function ()
-  {
-    if (!this._flavourSet) {
-      this._flavourSet = new FlavourSet();
-      var documentId = gToolboxDocument.documentElement.id;
-      this._flavourSet.appendFlavour("text/toolbarwrapper-id/"+documentId);
-    }
-    return this._flavourSet;
   }
+
+  gCurrentDragOverItem = null;
+
+  toolboxChanged();
+};
+
+function onPaletteDragOver(aEvent)
+{
+  var documentId = gToolboxDocument.documentElement.id;
+  if (aEvent.dataTransfer.types.contains("text/toolbarwrapper-id/" + documentId))
+    aEvent.preventDefault();
 }
 
+function onPaletteDrop(aEvent)
+ {
+  var documentId = gToolboxDocument.documentElement.id;
+  var itemId = aEvent.dataTransfer.getData("text/toolbarwrapper-id/" + documentId);
+
+  var wrapper = gToolboxDocument.getElementById("wrapper-"+itemId);
+  if (wrapper) {
+    // Don't allow static kids (e.g., the menubar) to move.
+    if (wrapper.parentNode.firstPermanentChild && wrapper.parentNode.firstPermanentChild.id == wrapper.firstChild.id)
+      return;
+    if (wrapper.parentNode.lastPermanentChild && wrapper.parentNode.lastPermanentChild.id == wrapper.firstChild.id)
+      return;
+
+    var wrapperType = wrapper.getAttribute("type");
+    if (wrapperType != "separator" &&
+        wrapperType != "spacer" &&
+        wrapperType != "spring") {
+      appendPaletteItem(document.importNode(wrapper.firstChild, true));
+      gToolbox.palette.appendChild(wrapper.firstChild);
+    }
+
+    // The item was dragged out of the toolbar.
+    wrapper.parentNode.removeChild(wrapper);
+  }
+
+  toolboxChanged();
+}
