@@ -1,9 +1,8 @@
-//@line 41 "/usr/obj/ports/mozilla-thunderbird-2.0.0.23p1/mozilla/toolkit/components/printing/content/printUtils.js"
-
-var  XUL_NS = "http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul";
+//@line 41 "/usr/obj/ports/mozilla-thunderbird-3.1.1/comm-1.9.2/mozilla/toolkit/components/printing/content/printUtils.js"
 
 var gPrintSettingsAreGlobal = false;
 var gSavePrintSettings = false;
+var gFocusedElement = null;
 
 var PrintUtils = {
 
@@ -27,9 +26,9 @@ var PrintUtils = {
     return true;
   },
 
-  print: function ()
+  print: function (aWindow)
   {
-    var webBrowserPrint = this.getWebBrowserPrint();
+    var webBrowserPrint = this.getWebBrowserPrint(aWindow);
     var printSettings = this.getPrintSettings();
     try {
       webBrowserPrint.print(printSettings, null);
@@ -49,7 +48,13 @@ var PrintUtils = {
     }
   },
 
-  printPreview: function (aEnterPPCallback, aExitPPCallback)
+  // calling PrintUtils.printPreview() requires that you have three functions
+  // in the global scope: getPPBrowser(), which returns the browser element in
+  // the window print preview uses, getNavToolbox(), which returns the element
+  // (usually the main toolbox element) before which the print preview toolbar
+  // should be inserted, and getWebNavigation(), which returns the document's
+  // nsIWebNavigation object
+  printPreview: function (aEnterPPCallback, aExitPPCallback, aWindow)
   {
     // if we're already in PP mode, don't set the callbacks; chances
     // are they're null because someone is calling printPreview() to
@@ -59,31 +64,33 @@ var PrintUtils = {
       this._onEnterPP = aEnterPPCallback;
       this._onExitPP  = aExitPPCallback;
     } else {
-      // hide the toolbar here -- it will be shown in
+      // collapse the browser here -- it will be shown in
       // onEnterPrintPreview; this forces a reflow which fixes display
       // issues in bug 267422.
-      pptoolbar.hidden = true;
+      var browser = getPPBrowser();
+      if (browser)
+        browser.collapsed = true;
     }
 
     this._webProgressPP = {};
     var ppParams        = {};
     var notifyOnOpen    = {};
-    var webBrowserPrint = this.getWebBrowserPrint();
+    var webBrowserPrint = this.getWebBrowserPrint(aWindow);
     var printSettings   = this.getPrintSettings();
     // Here we get the PrintingPromptService so we can display the PP Progress from script
     // For the browser implemented via XUL with the PP toolbar we cannot let it be
     // automatically opened from the print engine because the XUL scrollbars in the PP window
     // will layout before the content window and a crash will occur.
-    // Doing it all from script, means it lays out before hand and we can let printing do it's own thing
+    // Doing it all from script, means it lays out before hand and we can let printing do its own thing
     var PPROMPTSVC = Components.classes["@mozilla.org/embedcomp/printingprompt-service;1"]
                                .getService(Components.interfaces.nsIPrintingPromptService);
     // just in case we are already printing, 
     // an error code could be returned if the Prgress Dialog is already displayed
     try {
-      PPROMPTSVC.showProgress(this, webBrowserPrint, printSettings, this._obsPP, false,
+      PPROMPTSVC.showProgress(window, webBrowserPrint, printSettings, this._obsPP, false,
                               this._webProgressPP, ppParams, notifyOnOpen);
       if (ppParams.value) {
-        var webNav = getBrowser().webNavigation;
+        var webNav = getWebNavigation();
         ppParams.value.docTitle = webNav.document.title;
         ppParams.value.docURL   = webNav.currentURI.spec;
       }
@@ -97,10 +104,11 @@ var PrintUtils = {
     }
   },
 
-  getWebBrowserPrint: function ()
+  getWebBrowserPrint: function (aWindow)
   {
-    return _content.QueryInterface(Components.interfaces.nsIInterfaceRequestor)
-                   .getInterface(Components.interfaces.nsIWebBrowserPrint);
+    var contentWindow = aWindow || window.content;
+    return contentWindow.QueryInterface(Components.interfaces.nsIInterfaceRequestor)
+                        .getInterface(Components.interfaces.nsIWebBrowserPrint);
   },
 
   ////////////////////////////////////////
@@ -143,7 +151,7 @@ var PrintUtils = {
     return printSettings;
   },
 
-  _chromeState: {},
+  _originalZoomValue: null,
   _closeHandlerPP: null,
   _webProgressPP: null,
   _onEnterPP: null,
@@ -160,19 +168,31 @@ var PrintUtils = {
 
     QueryInterface : function(iid)
     {
-      if (iid.equals(Components.interfaces.nsIObserver) || iid.equals(Components.interfaces.nsISupportsWeakReference))
+      if (iid.equals(Components.interfaces.nsIObserver) ||
+          iid.equals(Components.interfaces.nsISupportsWeakReference) ||
+          iid.equals(Components.interfaces.nsISupports))
         return this;   
       throw Components.results.NS_NOINTERFACE;
     }
   },
 
-  enterPrintPreview: function ()
+  enterPrintPreview: function (aWindow)
   {
-    var webBrowserPrint = this.getWebBrowserPrint();
+    gFocusedElement = document.commandDispatcher.focusedElement;
+
+    // Reset the zoom value and save it to be restored later.
+    if (typeof ZoomManager == "object") {
+      this._originalZoomValue = ZoomManager.zoom;
+      ZoomManager.reset();
+    }
+
+    var webBrowserPrint = this.getWebBrowserPrint(aWindow);
     var printSettings   = this.getPrintSettings();
     try {
       webBrowserPrint.printPreview(printSettings, null, this._webProgressPP.value);
     } catch (e) {
+      if (typeof ZoomManager == "object")
+        ZoomManager.zoom = this._originalZoomValue;
       // Pressing cancel is expressed as an NS_ERROR_ABORT return value,
       // causing an exception to be thrown which we catch here.
       // Unfortunately this will also consume helpful failures, so add a
@@ -183,17 +203,23 @@ var PrintUtils = {
     var printPreviewTB = document.getElementById("print-preview-toolbar");
     if (printPreviewTB) {
       printPreviewTB.updateToolbar();
-      printPreviewTB.hidden = false;
+      var browser = getPPBrowser();
+      if (browser)
+        browser.collapsed = false;
       return;
     }
 
     // show the toolbar after we go into print preview mode so
     // that we can initialize the toolbar with total num pages
+    var XUL_NS =
+      "http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul";
     printPreviewTB = document.createElementNS(XUL_NS, "toolbar");
     printPreviewTB.setAttribute("printpreview", true);
-    printPreviewTB.setAttribute("id", "print-preview-toolbar");
+    printPreviewTB.id = "print-preview-toolbar";
+    printPreviewTB.className = "toolbar-primary";
 
-//@line 244 "/usr/obj/ports/mozilla-thunderbird-2.0.0.23p1/mozilla/toolkit/components/printing/content/printUtils.js"
+    var navToolbox = getNavToolbox();
+    navToolbox.parentNode.insertBefore(printPreviewTB, navToolbox);
 
     // copy the window close handler
     if (document.documentElement.hasAttribute("onclose"))
@@ -205,7 +231,8 @@ var PrintUtils = {
     // disable chrome shortcuts...
     window.addEventListener("keypress", this.onKeyPressPP, true);
  
-    _content.focus();
+    var contentWindow = aWindow || window.content;
+    contentWindow.focus();
 
     // on Enter PP Call back
     if (this._onEnterPP) {
@@ -214,30 +241,30 @@ var PrintUtils = {
     }
   },
 
-  exitPrintPreview: function ()
+  exitPrintPreview: function (aWindow)
   {
     window.removeEventListener("keypress", this.onKeyPressPP, true);
 
-//@line 269 "/usr/obj/ports/mozilla-thunderbird-2.0.0.23p1/mozilla/toolkit/components/printing/content/printUtils.js"
-    BrowserExitPrintPreview(); // make the traditional call..don't do any of the inline toolbar browser stuff
-    return;
-//@line 272 "/usr/obj/ports/mozilla-thunderbird-2.0.0.23p1/mozilla/toolkit/components/printing/content/printUtils.js"
-
     // restore the old close handler
     document.documentElement.setAttribute("onclose", this._closeHandlerPP);
     this._closeHandlerPP = null;
 
-    if ("getStripVisibility" in getBrowser())
-      getBrowser().setStripVisibilityTo(this._chromeState.hadTabStrip);
-
-    var webBrowserPrint = this.getWebBrowserPrint();
-    webBrowserPrint.exitPrintPreview(); 
+    var webBrowserPrint = this.getWebBrowserPrint(aWindow);
+    webBrowserPrint.exitPrintPreview();
+    if (typeof ZoomManager == "object")
+      ZoomManager.zoom = this._originalZoomValue;
 
     // remove the print preview toolbar
     var printPreviewTB = document.getElementById("print-preview-toolbar");
-    getBrowser().parentNode.removeChild(printPreviewTB);
+    getNavToolbox().parentNode.removeChild(printPreviewTB);
 
-    _content.focus();
+    var fm = Components.classes["@mozilla.org/focus-manager;1"]
+                       .getService(Components.interfaces.nsIFocusManager);
+    if (gFocusedElement)
+      fm.setFocus(gFocusedElement, fm.FLAG_NOSCROLL);
+    else
+      (aWindow || window.content).focus();
+    gFocusedElement = null;
 
     // on Exit PP Call back
     if (this._onExitPP) {
