@@ -1,4 +1,4 @@
-//@line 40 "/usr/obj/ports/mozilla-thunderbird-2.0.0.23p1/mozilla/toolkit/components/viewsource/content/viewPartialSource.js"
+//@line 40 "/usr/obj/ports/mozilla-thunderbird-3.1.1/comm-1.9.2/mozilla/toolkit/components/viewsource/content/viewPartialSource.js"
 
 var gDebug = 0;
 var gLineCount = 0;
@@ -37,20 +37,13 @@ function onLoadViewPartialSource()
   } else {
     document.getElementById("menu_highlightSyntax").setAttribute("hidden", "true");
   }
-  
-  gFindBar.initFindBar();
 
   if (window.arguments[3] == 'selection')
     viewPartialSourceForSelection(window.arguments[2]);
   else
     viewPartialSourceForFragment(window.arguments[2], window.arguments[3]);
 
-  window._content.focus();
-}
-
-function onUnloadViewPartialSource()
-{
-  gFindBar.uninitFindBar();
+  window.content.focus();
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -165,11 +158,11 @@ function viewPartialSourceForSelection(selection)
   // the load is aynchronous and so we will wait until the view-source DOM is done
   // before drawing the selection.
   if (canDrawSelection) {
-    window.document.getElementById("appcontent").addEventListener("load", drawSelection, true);
+    window.document.getElementById("content").addEventListener("load", drawSelection, true);
   }
 
   // all our content is held by the data:URI and URIs are internally stored as utf-8 (see nsIURI.idl)
-  var loadFlags = Components.interfaces.nsIWebNavigation.LOAD_FLAGS_BYPASS_CACHE;
+  var loadFlags = Components.interfaces.nsIWebNavigation.LOAD_FLAGS_NONE;
   getBrowser().webNavigation
               .loadURI("view-source:data:text/html;charset=utf-8," + encodeURIComponent(tmpNode.innerHTML),
                        loadFlags, null, null, null);
@@ -321,7 +314,8 @@ function viewPartialSourceForFragment(node, context)
   var title = getViewSourceBundle().getString("viewMathMLSourceTitle");
   var wrapClass = gWrapLongLines ? ' class="wrap"' : '';
   var source =
-    '<html>'
+    '<!DOCTYPE html>'
+  + '<html>'
   + '<head><title>' + title + '</title>'
   + '<link rel="stylesheet" type="text/css" href="' + gViewSourceCSS + '">'
   + '<style type="text/css">'
@@ -336,10 +330,7 @@ function viewPartialSourceForFragment(node, context)
   ; // end
 
   // display
-  var doc = getBrowser().contentDocument;
-  doc.open("text/html", "replace");
-  doc.write(source);
-  doc.close();
+  getBrowser().loadURI("data:text/html;charset=utf-8," + encodeURIComponent(source));
 }
 
 ////////////////////////////////////////////////////////////////////////////////
