@@ -1,4 +1,4 @@
-//@line 37 "/usr/obj/i386/mozilla-thunderbird-2.0.0.23p1/mozilla/mail/extensions/newsblog/content/Feed.js"
+//@line 37 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mailnews/extensions/newsblog/content/Feed.js"
 
 
 // error codes used to inform the consumer about attempts to download a feed
@@ -12,7 +12,7 @@ const kNewsBlogNoNewItems = 4; // there are no new articles for this feed
 // can access the Feed objects after it finishes downloading the feed.
 var FeedCache = 
 {
-  mFeeds: new Array(),
+  mFeeds: {},
 
   putFeed: function (aFeed)
   {
@@ -21,12 +21,17 @@ var FeedCache =
 
   getFeed: function (aUrl)
   {
-    return this.mFeeds[this.normalizeHost(aUrl)];
+    var index = this.normalizeHost(aUrl);
+    if (index in this.mFeeds)
+      return this.mFeeds[index];
+    return null;
   },
 
   removeFeed: function (aUrl)
   {
-    delete this.mFeeds[this.normalizeHost(aUrl)];
+    var index = this.normalizeHost(aUrl);
+    if (index in this.mFeeds)
+      delete this.mFeeds[index];
   },
 
   normalizeHost: function (aUrl)
@@ -55,6 +60,7 @@ Feed.prototype =
   resource: null,
   items: new Array(),
   mFolder: null,
+  mInvalidFeed: false,
 
   get folder()
   {
@@ -108,7 +114,10 @@ Feed.prototype =
                         createInstance(Components.interfaces.nsIURI);
     uri.spec = this.url;
     if (!(uri.schemeIs("http") || uri.schemeIs("https")))
-      return this.onParseError(this); // simulate an invalid feed error
+    {
+      this.onParseError(this); // simulate an invalid feed error
+      return;
+    }
 
     // Before we try to download the feed, make sure we aren't already processing the feed
     // by looking up the url in our feed cache
@@ -140,6 +149,11 @@ Feed.prototype =
     var request = aEvent.target;
     var url = request.channel.originalURI.spec;
     debug(url + " downloaded");
+    if (request.status < 200 || request.status >= 300)
+    {
+      Feed.prototype.onDownloadError(aEvent);
+      return;
+    }
     var feed = FeedCache.getFeed(url);
     if (!feed)
       throw("error after downloading " + url + ": couldn't retrieve feed from request");
@@ -185,10 +199,13 @@ Feed.prototype =
 
   onParseError: function(aFeed) 
   {
-    if (aFeed && aFeed.downloadCallback)
+    if (aFeed)
     {
+      aFeed.mInvalidFeed = true;
+
       if (aFeed.downloadCallback)
-        aFeed.downloadCallback.downloaded(aFeed, aFeed.request && aFeed.request.status == 304 ? kNewsBlogNoNewItems : kNewsBlogInvalidFeed);
+        aFeed.downloadCallback.downloaded(aFeed, kNewsBlogInvalidFeed);
+
       FeedCache.removeFeed(aFeed.url);
     }
   },
@@ -306,12 +323,22 @@ Feed.prototype =
     debug("parsing feed " + this.url);
 
     if (!this.request.responseText) 
-      return this.onParseError(this);
+    {
+      this.onParseError(this);
+      return;
+    }
       
     // create a feed parser which will parse the feed for us
     var parser = new FeedParser();
     this.itemsToStore = parser.parseFeed(this, this.request.responseText, this.request.responseXML, this.request.channel.URI);
   
+    if (this.mInvalidFeed)
+    {
+      this.request = null;
+      this.mInvalidFeed = false;
+      return;
+    }
+
     // storeNextItem will iterate through the parsed items, storing each one.
     this.itemsToStoreIndex = 0;
     this.storeNextItem();
@@ -341,12 +368,23 @@ Feed.prototype =
     debug("removing invalid items for " + this.url);
     var items = ds.GetSources(FZ_FEED, this.resource, true);
     var item;
+    var currentTime = new Date().getTime();
     while (items.hasMoreElements()) 
     {
       item = items.getNext();
       item = item.QueryInterface(Components.interfaces.nsIRDFResource);
+
       if (ds.HasAssertion(item, FZ_VALID, RDF_LITERAL_TRUE, true))
         continue;
+
+      var lastSeenTime = ds.GetTarget(item, FZ_LAST_SEEN_TIMESTAMP, true);
+      lastSeenTime = lastSeenTime ?
+                     parseInt(lastSeenTime
+                              .QueryInterface(Components.interfaces.nsIRDFLiteral)
+                              .Value) : 0;
+      if ((currentTime - lastSeenTime) < INVALID_ITEM_PURGE_DELAY)
+        continue;
+
       debug("removing " + item.Value);
       ds.Unassert(item, FZ_FEED, this.resource, true);
       if (ds.hasArcOut(item, FZ_FEED))
@@ -370,20 +408,20 @@ Feed.prototype =
     if (!this.itemsToStore ||  !this.itemsToStore.length)
     {
       this.createFolder();
-      return this.cleanupParsingState(this);
+      this.cleanupParsingState(this);
+      return;
     }
 
     var item = this.itemsToStore[this.itemsToStoreIndex]; 
 
     item.store();
-    item.markValid();
+
+    this.itemsToStoreIndex++;
 
     // if the listener is tracking progress for storing each item, report it here...
     if (item.feed.downloadCallback && item.feed.downloadCallback.onFeedItemStored)
       item.feed.downloadCallback.onFeedItemStored(item.feed, this.itemsToStoreIndex, this.itemsToStore.length);
  
-    this.itemsToStoreIndex++
-
     // eventually we'll report individual progress here....
 
     if (this.itemsToStoreIndex < this.itemsToStore.length)
@@ -399,7 +437,11 @@ Feed.prototype =
       // so the right RDF UI changes happen in the folder pane to indicate new mail.
 
       if (item.feed.folder.hasNewMessages)
+      {
         item.feed.folder.biffState = Components.interfaces.nsIMsgFolder.nsMsgBiffState_NewMail;
+        // run the bayesian spam filter, if enabled
+        item.feed.folder.callFilterPlugins(null);
+      }
       this.cleanupParsingState(item.feed);   
     }
   },
@@ -433,8 +475,7 @@ Feed.prototype =
     if (aIID.equals(Components.interfaces.nsITimerCallback) || aIID.equals(Components.interfaces.nsISupports))
       return this;
 
-    Components.returnCode = Components.results.NS_ERROR_NO_INTERFACE;
-    return null;    
+    throw Components.results.NS_ERROR_NO_INTERFACE;
   }
 };
 
