@@ -1,4 +1,4 @@
-//@line 37 "/usr/obj/i386/mozilla-thunderbird-2.0.0.23p1/mozilla/mail/extensions/newsblog/content/FeedItem.js"
+//@line 37 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mailnews/extensions/newsblog/content/FeedItem.js"
 
 // Handy conversion values.
 const HOURS_TO_MINUTES = 60;
@@ -6,7 +6,6 @@ const MINUTES_TO_SECONDS = 60;
 const SECONDS_TO_MILLISECONDS = 1000;
 const MINUTES_TO_MILLISECONDS = MINUTES_TO_SECONDS * SECONDS_TO_MILLISECONDS;
 const HOURS_TO_MILLISECONDS = HOURS_TO_MINUTES * MINUTES_TO_MILLISECONDS;
-const MSG_FLAG_NEW      = 0x10000;
 const ENCLOSURE_BOUNDARY_PREFIX = "--------------";  // 14 dashes
 const ENCLOSURE_HEADER_BOUNDARY_PREFIX = "------------"; // 12 dashes
 
@@ -15,71 +14,34 @@ const MESSAGE_TEMPLATE = "\n\
   <head>\n\
     <title>%TITLE%</title>\n\
     <base href=\"%BASE%\">\n\
-    <style type=\"text/css\">\n\
-      %STYLE%\n\
-    </style>\n\
   </head>\n\
-  <body>\n\
-    %CONTENT_TEMPLATE%\n\
+  <body id=\"msgFeedSummaryBody\" selected=\"false\">\n\
+    %CONTENT%\n\
   </body>\n\
 </html>\n\
 ";
 
-const REMOTE_CONTENT_TEMPLATE = "\n\
-    <iframe id =\"_mailrssiframe\" src=\"%URL%\">\n\
-      %DESCRIPTION%\n\
-    </iframe>\n\
-";
-
-const REMOTE_STYLE = "\n\
-      body {\n\
-        margin: 0;\n\
-        border: none;\n\
-        padding: 0;\n\
-      }\n\
-      iframe {\n\
-        position: fixed;\n\
-        top: 0;\n\
-        left: 0;\n\
-        width: 100%;\n\
-        height: 100%;\n\
-        border: none;\n\
-      }\n\
-";
-
-// Unlike remote content, which is locked within a fixed position iframe,
-// local content goes is positioned according to the normal rules of flow.
-// The problem with this is that the message pane itself provides a scrollbar
-// if necessary, and that scrollbar appears next to the toolbar as well as
-// the content being scrolled.  The solution is to lock local content within
-// a fixed position div and set its overflow property to auto so that the div
-// itself provides the scrollbar.  Unfortunately we can't do that because of
-// Mozilla bug 97283, which makes it hard to scroll an auto overflow div.
-
-const LOCAL_CONTENT_TEMPLATE = "\n\
-      %CONTENT%\n\
-";
-
-// no local style overrides at this time
-const LOCAL_STYLE = "\n";
-
-function FeedItem() 
+function FeedItem()
 {
   this.mDate = new Date().toString();
   this.mUnicodeConverter = Components.classes["@mozilla.org/intl/scriptableunicodeconverter"]
-                          .createInstance(Components.interfaces.nsIScriptableUnicodeConverter);
+                                     .createInstance(Components.interfaces.nsIScriptableUnicodeConverter);
 }
 
-FeedItem.prototype = 
+FeedItem.prototype =
 {
-  isStoredWithId: false, // we currently only do this for IETF Atom. RSS2 with GUIDs should do this as well.
-  xmlContentBase: null, // only for IETF Atom
+  // Currently only for IETF Atom. RSS2 with GUIDs should do this as too.
+  isStoredWithId: false,
+  // Only for IETF Atom
+  xmlContentBase: null,
   id: null,
   feed: null,
   description: null,
   content: null,
-  enclosure: null,  // we currently only support one enclosure per feed item...
-  title: "(no subject)",  // TO DO: this needs to be localized
+  // Currently only support one enclosure per feed item...
+  enclosure: null,
+  // TO DO: this needs to be localized
+  title: "(no subject)",
   author: "anonymous",
   mURL: null,
   characterSet: "",
@@ -91,7 +53,8 @@ FeedItem.prototype =
 
   set url(aVal)
   {
-    var uri = Components.classes["@mozilla.org/network/standard-url;1"].getService(Components.interfaces["nsIStandardURL"]);
+    var uri = Components.classes["@mozilla.org/network/standard-url;1"]
+                        .getService(Components.interfaces["nsIStandardURL"]);
     uri.init(1, 80, aVal, null, null);
     var uri = uri.QueryInterface(Components.interfaces.nsIURI);
     this.mURL = uri.spec;
@@ -116,6 +79,11 @@ FeedItem.prototype =
   {
     var messageID = this.id || this.mURL || this.title;
 
+    debug('messageID - id = ' + this.id);
+    debug('messageID - mURL = ' + this.mURL);
+    debug('messageID - title = ' + this.title);
+    debug('messageID - messageID = ' + messageID);
+
     // Escape occurrences of message ID meta characters <, >, and @.
     messageID.replace(/</g, "%3C");
     messageID.replace(/>/g, "%3E");
@@ -126,12 +94,8 @@ FeedItem.prototype =
 
   get itemUniqueURI()
   {
-    var theURI;
-    if(this.isStoredWithId && this.id)
-      theURI = "urn:" + this.id;
-    else
-      theURI = this.mURL || ("urn:" + this.id);
-    return theURI;
+    return (this.isStoredWithId && this.id) ? createURN(this.id) :
+           createURN(this.mURL || this.id);
   },
 
   get contentBase()
@@ -142,58 +106,37 @@ FeedItem.prototype =
       return this.mURL;
   },
 
-  store: function() 
+  store: function()
   {
     this.mUnicodeConverter.charset = this.characterSet;
 
-    if (this.isStored()) 
-      debug(this.identity + " already stored; ignoring");
-    else if (this.content) 
-    {
-      debug(this.identity + " has content; storing");
-      var content = MESSAGE_TEMPLATE;
-      content = content.replace(/%CONTENT_TEMPLATE%/, LOCAL_CONTENT_TEMPLATE);
-      content = content.replace(/%STYLE%/, LOCAL_STYLE);
-      content = content.replace(/%TITLE%/, this.title);
-      content = content.replace(/%BASE%/, this.contentBase); 
-      content = content.replace(/%URL%/g, this.mURL);
-      content = content.replace(/%CONTENT%/, this.content);
-      this.content = content; // XXX store it elsewhere, f.e. this.page
-      this.writeToFolder();
-    }
-    else if (this.feed.quickMode) 
-    {
-      debug(this.identity + " in quick mode; storing");
+    // this.title and this.content contain HTML
+    // this.mUrl and this.contentBase contain plain text
 
-      this.content = this.description || this.title;
-
-      var content = MESSAGE_TEMPLATE;
-      content = content.replace(/%CONTENT_TEMPLATE%/, LOCAL_CONTENT_TEMPLATE);
-      content = content.replace(/%STYLE%/, LOCAL_STYLE);
-      content = content.replace(/%BASE%/, this.contentBase); 
-      content = content.replace(/%TITLE%/, this.title);
-      content = content.replace(/%URL%/g, this.mURL);
-      content = content.replace(/%CONTENT%/, this.content);
-      this.content = content; // XXX store it elsewhere, f.e. this.page
-      this.writeToFolder();
-    } 
-    else 
+    let resource = this.findStoredResource();
+    if (resource == null)
     {
-      //debug(this.identity + " needs content; downloading");
-      debug(this.identity + " needs content; creating and storing");
+      resource = rdf.GetResource(this.itemUniqueURI);
+      if (!this.content)
+      {
+        debug(this.identity + " no content; storing");
+        this.content = this.description || this.title;
+      }
+
+      debug(this.identity + " store both remote/no content and content items");
       var content = MESSAGE_TEMPLATE;
-      content = content.replace(/%CONTENT_TEMPLATE%/, REMOTE_CONTENT_TEMPLATE);
-      content = content.replace(/%STYLE%/, REMOTE_STYLE);
       content = content.replace(/%TITLE%/, this.title);
-      content = content.replace(/%BASE%/, this.contentBase); 
-      content = content.replace(/%URL%/g, this.mURL);
-      content = content.replace(/%DESCRIPTION%/, this.description || this.title);
-      this.content = content; // XXX store it elsewhere, f.e. this.page
+      content = content.replace(/%BASE%/, htmlEscape(this.contentBase));
+      content = content.replace(/%CONTENT%/, this.content);
+      // XXX store it elsewhere, f.e. this.page
+      this.content = content;
       this.writeToFolder();
+      this.markStored(resource);
     }
+    this.markValid(resource);
   },
 
-  isStored: function()
+  findStoredResource: function()
   {
     // Checks to see if the item has already been stored in its feed's message folder.
 
@@ -202,14 +145,15 @@ FeedItem.prototype =
     var server = this.feed.server;
     var folder = this.feed.folder;
 
-    if (!folder) 
+    if (!folder)
     {
       debug(this.feed.name + " folder doesn't exist; creating");
-		  debug("creating " + this.feed.name + "as child of " + server.rootMsgFolder + "\n");
+      debug("creating " + this.feed.name + "as child of " +
+          server.rootMsgFolder + "\n");
       server.rootMsgFolder.createSubfolder(this.feed.name, null /* supposed to be a msg window */);
-      folder = server.rootMsgFolder.FindSubFolder(this.feed.name);
+      folder = server.rootMsgFolder.findSubFolder(this.feed.name);
       debug(this.identity + " not stored (folder didn't exist)");
-      return false;
+      return null;
     }
 
     var ds = getItemsDS(server);
@@ -218,113 +162,124 @@ FeedItem.prototype =
 
     var downloaded = ds.GetTarget(itemResource, FZ_STORED, true);
 
-    // Backward compatibility: we might have stored this item before isStoredWithId
-    // has been turned on for RSS 2.0 (bug 354345). Check whether this item has been
-    // stored with its URL.
-    if (!downloaded && itemURI != this.mURL)
+    // Backward compatibility: we might have stored this item before
+    // isStoredWithId has been turned on for RSS 2.0 (bug 354345).
+    // Check whether this item has been stored with its URL.
+    if (!downloaded && this.mURL && itemURI != this.mURL)
     {
       itemResource = rdf.GetResource(this.mURL);
       downloaded = ds.GetTarget(itemResource, FZ_STORED, true);
     }
 
-    if (!downloaded || downloaded.QueryInterface(Components.interfaces.nsIRDFLiteral).Value == "false") 
+    // Backward compatibility: the item may have been stored
+    // using the previous unique URI algorithm.
+    // (bug 410842 & bug 461109)
+    if (!downloaded)
     {
-      // HACK ALERT: before we give up, try to work around an entity escaping bug in RDF
-      // See Bug #258465 for more details
+      itemResource = rdf.GetResource((this.isStoredWithId && this.id) ?
+                                     ("urn:" + this.id) :
+                                     (this.mURL || ("urn:" + this.id)));
+      downloaded = ds.GetTarget(itemResource, FZ_STORED, true);
+    }
+
+    if (!downloaded ||
+        downloaded.QueryInterface(Components.interfaces.nsIRDFLiteral)
+                  .Value == "false")
+    {
+      // HACK ALERT: before we give up, try to work around an entity
+      // escaping bug in RDF. See Bug #258465 for more details
       itemURI = itemURI.replace(/&lt;/g, '<');
       itemURI = itemURI.replace(/&gt;/g, '>');
       itemURI = itemURI.replace(/&quot;/g, '"');
-      itemURI = itemURI.replace(/&amp;/g, '&');     
+      itemURI = itemURI.replace(/&amp;/g, '&');
 
       debug('Failed to find item, trying entity replacement version: '  + itemURI);
       itemResource = rdf.GetResource(itemURI);
       downloaded = ds.GetTarget(itemResource, FZ_STORED, true);
 
       if (downloaded)
-      { 
-        debug(this.identity + " not stored");
-        return true;
+      {
+        debug(this.identity + " stored");
+        return itemResource;
       }
 
       debug(this.identity + " not stored");
-      return false;
+      return null;
     }
-    else 
+    else
     {
       debug(this.identity + " stored");
-      return true;
+      return itemResource;
     }
   },
 
-  markValid: function() 
+  markValid: function(resource)
   {
-    debug("validating " + this.mURL);
     var ds = getItemsDS(this.feed.server);
 
-    var itemURI = this.itemUniqueURI;
-    var resource = rdf.GetResource(itemURI);
-    
-    // Backward compatibility: we might have stored this item before isStoredWithId
-    // has been turned on for RSS 2.0 (bug 354345). Check whether this item has been
-    // stored with its URL.
-    if (!ds.GetTarget(resource, FZ_STORED, true) && itemURI != this.mURL)
-      resource = rdf.GetResource(this.mURL);
+    var newTimeStamp = rdf.GetLiteral(new Date().getTime());
+    var currentTimeStamp = ds.GetTarget(resource, FZ_LAST_SEEN_TIMESTAMP, true);
+    if (currentTimeStamp)
+      ds.Change(resource, FZ_LAST_SEEN_TIMESTAMP, currentTimeStamp, newTimeStamp);
+    else
+      ds.Assert(resource, FZ_LAST_SEEN_TIMESTAMP, newTimeStamp, true);
 
     if (!ds.HasAssertion(resource, FZ_FEED, rdf.GetResource(this.feed.url), true))
       ds.Assert(resource, FZ_FEED, rdf.GetResource(this.feed.url), true);
-    
-    if (ds.hasArcOut(resource, FZ_VALID)) 
+
+    if (ds.hasArcOut(resource, FZ_VALID))
     {
       var currentValue = ds.GetTarget(resource, FZ_VALID, true);
       ds.Change(resource, FZ_VALID, currentValue, RDF_LITERAL_TRUE);
     }
-    else 
+    else
       ds.Assert(resource, FZ_VALID, RDF_LITERAL_TRUE, true);
   },
 
-  markStored: function() 
+  markStored: function(resource)
   {
     var ds = getItemsDS(this.feed.server);
-    var itemURI = this.itemUniqueURI;
-    var resource = rdf.GetResource(itemURI);
-   
+
     if (!ds.HasAssertion(resource, FZ_FEED, rdf.GetResource(this.feed.url), true))
       ds.Assert(resource, FZ_FEED, rdf.GetResource(this.feed.url), true);
-    
+
     var currentValue;
-    if (ds.hasArcOut(resource, FZ_STORED)) 
+    if (ds.hasArcOut(resource, FZ_STORED))
     {
       currentValue = ds.GetTarget(resource, FZ_STORED, true);
       ds.Change(resource, FZ_STORED, currentValue, RDF_LITERAL_TRUE);
     }
-    else 
+    else
       ds.Assert(resource, FZ_STORED, RDF_LITERAL_TRUE, true);
   },
 
   mimeEncodeSubject: function(aSubject, aCharset)
-  {  
-    // get the mime header encoder service
-    var mimeEncoder = Components.classes["@mozilla.org/messenger/mimeconverter;1"].getService(Components.interfaces.nsIMimeConverter);
+  {
+    // Get the mime header encoder service
+    var mimeEncoder = Components.classes["@mozilla.org/messenger/mimeconverter;1"]
+                                .getService(Components.interfaces.nsIMimeConverter);
 
-    // this routine sometimes throws exceptions for mis-encoded data so wrap it 
-    // with a try catch for now..
+    // This routine sometimes throws exceptions for mis-encoded data so
+    // wrap it with a try catch for now..
     var newSubject;
-    try 
+    try
     {
-      newSubject = mimeEncoder.encodeMimePartIIStr(this.mUnicodeConverter.ConvertFromUnicode(aSubject), false, aCharset, 9, 72);
+      newSubject = mimeEncoder.encodeMimePartIIStr(
+          this.mUnicodeConverter.ConvertFromUnicode(aSubject),
+          false, aCharset, 9, 72);
     }
-    catch (ex) 
-    { 
-      newSubject = aSubject; 
+    catch (ex)
+    {
+      newSubject = aSubject;
     }
 
     return newSubject;
-  }, 
+  },
 
-  writeToFolder: function() 
+  writeToFolder: function()
   {
     debug(this.identity + " writing to message folder" + this.feed.name + "\n");
-  
+
     var server = this.feed.server;
     this.mUnicodeConverter.charset = this.characterSet;
 
@@ -332,9 +287,9 @@ FeedItem.prototype =
     if (this.author && this.author.indexOf('@') == -1)
       this.author = '<' + this.author + '>';
 
-    // Convert the title to UTF-16 before performing our HTML entity replacement
-    // reg expressions.
-    var title = this.title; 
+    // Convert the title to UTF-16 before performing our HTML entity
+    // replacement reg expressions.
+    var title = this.title;
 
     // the subject may contain HTML entities.
     // Convert these to their unencoded state. i.e. &amp; becomes '&'
@@ -342,7 +297,7 @@ FeedItem.prototype =
     title = title.replace(/&gt;/g, '>');
     title = title.replace(/&quot;/g, '"');
     title = title.replace(/&amp;/g, '&');
-  
+
     // Compress white space in the subject to make it look better.
     title = title.replace(/[\t\r\n]+/g, " ");
 
@@ -353,17 +308,18 @@ FeedItem.prototype =
     if (this.mDate.search(/^\d\d\d\d/) != -1)
       this.mDate = W3CToIETFDate(this.mDate);
 
-    // Escape occurrences of "From " at the beginning of lines of content
-    // per the mbox standard, since "From " denotes a new message, and add
-    // a line break so we know the last line has one.
+    // Escape occurrences of "From " at the beginning of lines of
+    // content per the mbox standard, since "From " denotes a new
+    // message, and add a line break so we know the last line has one.
     this.content = this.content.replace(/([\r\n]+)(>*From )/g, "$1>$2");
     this.content += "\n";
 
-    // The opening line of the message, mandated by standards to start with
-    // "From ".  It's useful to construct this separately because we not only
-    // need to write it into the message, we also need to use it to calculate
-    // the offset of the X-Mozilla-Status lines from the front of the message
-    // for the statusOffset property of the DB header object.
+    // The opening line of the message, mandated by standards to start
+    // with "From ".  It's useful to construct this separately because
+    // we not only need to write it into the message, we also need to
+    // use it to calculate the offset of the X-Mozilla-Status lines from
+    // the front of the message for the statusOffset property of the
+    // DB header object.
     var openingLine = 'From - ' + this.mDate + '\n';
 
     var source =
@@ -385,7 +341,7 @@ FeedItem.prototype =
       source += 'Content-Type: multipart/mixed;\n boundary="' + ENCLOSURE_HEADER_BOUNDARY_PREFIX + boundaryID + '"' + '\n\n' +
                 'This is a multi-part message in MIME format.\n' + ENCLOSURE_BOUNDARY_PREFIX + boundaryID + '\n' +
                 'Content-Type: text/html; charset=' + this.characterSet + '\n' +
-                'Content-Transfer-Encoding: 8bit\n' + 
+                'Content-Transfer-Encoding: 8bit\n' +
                 this.content;
       source += this.enclosure.convertToAttachment(boundaryID);
     }
@@ -393,19 +349,19 @@ FeedItem.prototype =
     {
       source += 'Content-Type: text/html; charset=' + this.characterSet + '\n' +
                 '\n' + this.content;
-               
+
     }
 
     debug(this.identity + " is " + source.length + " characters long");
 
     // Get the folder and database storing the feed's messages and headers.
-    folder = this.feed.folder.QueryInterface(Components.interfaces.nsIMsgLocalMailFolder);
+    var folder = this.feed.folder.QueryInterface(Components.interfaces.nsIMsgLocalMailFolder);
     var msgFolder = folder.QueryInterface(Components.interfaces.nsIMsgFolder);
     msgFolder.gettingNewMessages = true;
-    // source is a unicode string, we want to save a char * string in the original charset. So convert back
+    // Source is a unicode string, we want to save a char * string in
+    // the original charset. So convert back
     folder.addMessage(this.mUnicodeConverter.ConvertFromUnicode(source));
     msgFolder.gettingNewMessages = false;
-    this.markStored();
   }
 };
 
@@ -413,7 +369,7 @@ FeedItem.prototype =
 // A feed enclosure is to RSS what an attachment is for e-mail. We make enclosures look
 // like attachments in the UI.
 
-function FeedEnclosure(aURL, aContentType, aLength) 
+function FeedEnclosure(aURL, aContentType, aLength)
 {
   this.mURL = aURL;
   this.mContentType = aContentType;
@@ -422,33 +378,33 @@ function FeedEnclosure(aURL, aContentType, aLength)
   // generate a fileName from the URL
   if (this.mURL)
   {
-    var ioService = Components.classes["@mozilla.org/network/io-service;1"].getService(Components.interfaces.nsIIOService);
-    var enclosureURL  = ioService.newURI(this.mURL, null, null).QueryInterface(Components.interfaces.nsIURL);
+    var ioService = Components.classes["@mozilla.org/network/io-service;1"]
+                              .getService(Components.interfaces.nsIIOService);
+    var enclosureURL  = ioService.newURI(this.mURL, null, null)
+                                 .QueryInterface(Components.interfaces.nsIURL);
     if (enclosureURL)
       this.mFileName = enclosureURL.fileName;
   }
 }
 
-FeedEnclosure.prototype = 
+FeedEnclosure.prototype =
 {
   mURL: "",
   mContentType: "",
   mLength: 0,
   mFileName: "",
 
-  // returns a string that looks like an e-mail attachment
-  // which represents the enclosure.
+  // Returns a string that looks like an e-mail attachment which
+  // represents the enclosure.
   convertToAttachment: function(aBoundaryID)
   {
     return '\n' +
                   ENCLOSURE_BOUNDARY_PREFIX + aBoundaryID + '\n' +
-                  'Content-Type: ' + this.mContentType + '; name="' + this.mFileName + '"\n' + 
+                  'Content-Type: ' + this.mContentType + '; name="' + this.mFileName + '"\n' +
                   'X-Mozilla-External-Attachment-URL: ' + this.mURL + '\n' +
-                  'Content-Disposition: attachment; filename="' + this.mFileName + '"\n\n' + 
+                  'Content-Disposition: attachment; filename="' + this.mFileName + '"\n\n' +
                   'This MIME attachment is stored separately from the message.\n' +
                   ENCLOSURE_BOUNDARY_PREFIX + aBoundaryID + '--' + '\n';
 
   }
 };
-
-
