@@ -1,4 +1,4 @@
-//@line 38 "/usr/obj/ports/mozilla-thunderbird-2.0.0.23p1/mozilla/mail/extensions/smime/content/msgHdrViewSMIMEOverlay.js"
+//@line 38 "/usr/obj/ports/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/extensions/smime/content/msgHdrViewSMIMEOverlay.js"
 
 var gSignedUINode = null;
 var gEncryptedUINode = null;
@@ -82,10 +82,10 @@ var smimeHeaderSink =
       gEncryptedUINode.setAttribute("encrypted", "notok");
       gStatusBar.setAttribute("encrypted", "notok");
     }
-    
+
     if (gEncryptedURIService)
     {
-      gMyLastEncryptedURI = GetLoadedMessage();
+      gMyLastEncryptedURI = gFolderDisplay.selectedMessageUris[0];
       gEncryptedURIService.rememberEncrypted(gMyLastEncryptedURI);
     }
 
@@ -198,6 +198,10 @@ function msgHdrViewSMIMEOnUnload(event)
   document.removeEventListener("smartcard-insert", onSmartCardChange, false);
   document.removeEventListener("smartcard-remove", onSmartCardChange, false);
   forgetEncryptedURI();
+  removeEventListener('messagepane-loaded', msgHdrViewSMIMEOnLoad, true);
+  removeEventListener('messagepane-unloaded', msgHdrViewSMIMEOnUnload, true);
+  removeEventListener('messagepane-hide', msgHdrViewSMIMEOnMessagePaneHide, true);
+  removeEventListener('messagepane-unhide', msgHdrViewSMIMEOnMessagePaneUnhide, true);
 }
 
 function msgHdrViewSMIMEOnMessagePaneHide()
