@@ -1,4 +1,4 @@
-//@line 36 "/usr/obj/ports/mozilla-thunderbird-2.0.0.23p1/mozilla/mail/base/content/ABSearchDialog.js"
+//@line 36 "/usr/obj/ports/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/base/content/ABSearchDialog.js"
 
 var searchSessionContractID = "@mozilla.org/messenger/searchSession;1";
 var gSearchSession;
@@ -25,14 +25,17 @@ var gSearchAbViewListener = {
     UpdateCardView();
   },
   onCountChanged: function(total) {
-    if (total == 0)
-      var statusText = gAddressBookBundle.getString("noMatchFound");
-    else
-    {
-      if (total == 1)
-        var statusText = gAddressBookBundle.getString("matchFound");
-      else  
-        var statusText = gAddressBookBundle.getFormattedString("matchesFound", [total]);
+    var statusText;
+    switch (total) {
+      case 0:
+        statusText = gAddressBookBundle.getString("noMatchFound");
+        break;
+      case 1:
+        statusText = gAddressBookBundle.getString("matchFound");
+        break;
+      default:
+        statusText = gAddressBookBundle.getFormattedString("matchesFound", [total]);
+        break;
     }
     gStatusText.setAttribute("label", statusText);
   }
@@ -59,10 +62,12 @@ function searchOnLoad()
 
   if (window.arguments && window.arguments[0])
     SelectDirectory(window.arguments[0].directory);
+  else
+    SelectDirectory(document.getElementById("abPopup-menupopup")
+                            .firstChild.value);
 
   // initialize globals, see abCommon.js, InitCommonJS()
   abList = document.getElementById("abPopup");
-  gAbResultsTree = document.getElementById("abResultsTree");
 
   onMore(null);
 }
@@ -276,7 +281,7 @@ function onSearch()
     }
 
     searchUri += ")";
-    SetAbView(searchUri, null, null);
+    SetAbView(searchUri);
 }
 
 // used to toggle functionality for Search/Stop button.
@@ -331,11 +336,3 @@ function UpdateCardView()
   else
     gPropertiesButton.setAttribute("disabled","true");
 }
-
-function onChooseDirectory(event) 
-{
-    var directoryURI = event.id;
-    if (directoryURI) {
-        SelectDirectory(directoryURI);
-    }
-}
