@@ -1,6 +1,6 @@
-//@line 38 "/usr/obj/ports/mozilla-thunderbird-2.0.0.23p1/mozilla/mail/components/compose/content/addressingWidgetOverlay.js"
+//@line 38 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/components/compose/content/addressingWidgetOverlay.js"
 
-top.MAX_RECIPIENTS = 0;
+top.MAX_RECIPIENTS = 1; /* for the initial listitem created in the XUL */
 
 var inputElementType = "";
 var selectElementType = "";
@@ -67,7 +67,7 @@ function awGetSelectItemIndex(itemData)
       selectElementIndexTable[aData] = i;
     }
   }
-  
+
   return selectElementIndexTable[itemData];
 }
 
@@ -125,7 +125,7 @@ function Recipients2CompFields(msgCompFields)
           case "addr_to"          : addrTo += to_Sep + recipient; to_Sep = ",";               break;
           case "addr_cc"          : addrCc += cc_Sep + recipient; cc_Sep = ",";               break;
           case "addr_bcc"         : addrBcc += bcc_Sep + recipient; bcc_Sep = ",";            break;
-          case "addr_reply"       : addrReply += reply_Sep + recipient; reply_Sep = ",";      break; 
+          case "addr_reply"       : addrReply += reply_Sep + recipient; reply_Sep = ",";      break;
           case "addr_newsgroups"  : addrNg += ng_Sep + fieldValue; ng_Sep = ",";              break;
           case "addr_followup"    : addrFollow += follow_Sep + fieldValue; follow_Sep = ",";  break;
           // do CRLF, same as PUSH_NEWLINE() in nsMsgSend.h / nsMsgCompUtils.cpp
@@ -150,7 +150,7 @@ function Recipients2CompFields(msgCompFields)
     dump("Message Compose Error: msgCompFields is null (ExtractRecipients)");
 }
 
-function CompFields2Recipients(msgCompFields, msgType)
+function CompFields2Recipients(msgCompFields)
 {
   if (msgCompFields) {
     gMimeHeaderParser = Components.classes["@mozilla.org/messenger/headerparser;1"].getService(Components.interfaces.nsIMsgHeaderParser);
@@ -160,7 +160,9 @@ function CompFields2Recipients(msgCompFields, msgType)
     var listBoxColsClone = listbox.firstChild.cloneNode(true);
     newListBoxNode.appendChild(listBoxColsClone);
     var templateNode = listbox.getElementsByTagName("listitem")[0];
-    
+    // dump("replacing child in comp fields 2 recips \n");
+    listbox.parentNode.replaceChild(newListBoxNode, listbox);
+
     top.MAX_RECIPIENTS = 0;
     var msgReplyTo = msgCompFields.replyTo;
     var msgTo = msgCompFields.to;
@@ -169,41 +171,55 @@ function CompFields2Recipients(msgCompFields, msgType)
     var msgRandomHeaders = msgCompFields.otherRandomHeaders;
     var msgNewsgroups = msgCompFields.newsgroups;
     var msgFollowupTo = msgCompFields.followupTo;
+    var havePrimaryRecipient = false;
     if(msgReplyTo)
-      awSetInputAndPopupFromArray(msgCompFields.SplitRecipients(msgReplyTo, false), 
+      awSetInputAndPopupFromArray(msgCompFields.splitRecipients(msgReplyTo, false, {}),
                                   "addr_reply", newListBoxNode, templateNode);
     if(msgTo)
-      awSetInputAndPopupFromArray(msgCompFields.SplitRecipients(msgTo, false), 
-                                  "addr_to", newListBoxNode, templateNode);
+    {
+      var rcp = msgCompFields.splitRecipients(msgTo, false, {});
+      if (rcp.length)
+      {
+        awSetInputAndPopupFromArray(rcp, "addr_to", newListBoxNode, templateNode);
+        havePrimaryRecipient = true;
+      }
+    }
     if(msgCC)
-      awSetInputAndPopupFromArray(msgCompFields.SplitRecipients(msgCC, false),
+      awSetInputAndPopupFromArray(msgCompFields.splitRecipients(msgCC, false, {}),
                                   "addr_cc", newListBoxNode, templateNode);
     if(msgBCC)
-      awSetInputAndPopupFromArray(msgCompFields.SplitRecipients(msgBCC, false),
+      awSetInputAndPopupFromArray(msgCompFields.splitRecipients(msgBCC, false, {}),
                                   "addr_bcc", newListBoxNode, templateNode);
     if(msgRandomHeaders)
       awSetInputAndPopup(msgRandomHeaders, "addr_other", newListBoxNode, templateNode);
     if(msgNewsgroups)
+    {
       awSetInputAndPopup(msgNewsgroups, "addr_newsgroups", newListBoxNode, templateNode);
+      havePrimaryRecipient = true;
+    }
     if(msgFollowupTo)
       awSetInputAndPopup(msgFollowupTo, "addr_followup", newListBoxNode, templateNode);
 
-    //If it's a new message, we need to add an extrat empty recipient.
-    if (!msgTo && !msgNewsgroups)
+    // If it's a new message, we need to add an extra empty recipient.
+    if (!havePrimaryRecipient)
       _awSetInputAndPopup("", "addr_to", newListBoxNode, templateNode);
-    // dump("replacing child in comp fields 2 recips \n");
-    var parent = listbox.parentNode;
-    parent.replaceChild(newListBoxNode, listbox);
     awFitDummyRows(2);
 
     // CompFields2Recipients is called whenever a user replies or edits an existing message. We want to
-    // add all of the recipients for this message to the ignore list for spell check 
+    // add all of the recipients for this message to the ignore list for spell check
     addRecipientsToIgnoreList((gCurrentIdentity ? gCurrentIdentity.identityName + ', ' : '') + msgTo + ', ' + msgCC + ', ' + msgBCC);
 
     gMimeHeaderParser = null; //Release the mime parser
   }
 }
 
+function awSetInputAndPopupId(inputElem, popupElem, rowNumber)
+{
+  popupElem.id = "addressCol1#" + rowNumber;
+  inputElem.id = "addressCol2#" + rowNumber;
+  inputElem.setAttribute("aria-labelledby", popupElem.id);
+}
+
 function awSetInputAndPopupValue(inputElem, inputValue, popupElem, popupValue, rowNumber)
 {
   // remove leading spaces
@@ -216,10 +232,7 @@ function awSetInputAndPopupValue(inputElem, inputValue, popupElem, popupValue, r
   popupElem.selectedItem = popupElem.childNodes[0].childNodes[awGetSelectItemIndex(popupValue)];
 
   if (rowNumber >= 0)
-  {
-    inputElem.setAttribute("id", "addressCol2#" + rowNumber);
-    popupElem.setAttribute("id", "addressCol1#" + rowNumber);
-  }
+    awSetInputAndPopupId(inputElem, popupElem, rowNumber);
 
   _awSetAutoComplete(popupElem, inputElem);
 }
@@ -251,18 +264,19 @@ function awSetInputAndPopup(inputValue, popupValue, parentNode, templateNode)
 
 function awSetInputAndPopupFromArray(inputArray, popupValue, parentNode, templateNode)
 {
-  if ( inputArray && popupValue )
+  if (popupValue)
   {
     var recipient;
-    for ( var index = 0; index < inputArray.count; index++ )
+    for (var index = 0; index < inputArray.length; index++)
     {
       recipient = null;
       if (gMimeHeaderParser)
         try {
-          recipient = gMimeHeaderParser.unquotePhraseOrAddrWString(inputArray.StringAt(index), true);
+          recipient =
+            gMimeHeaderParser.unquotePhraseOrAddrWString(inputArray[index], true);
         } catch (ex) {};
       if (!recipient)
-        recipient = inputArray.StringAt(index)
+        recipient = inputArray[index];
       _awSetInputAndPopup(recipient, popupValue, parentNode, templateNode);
     }
   }
@@ -270,21 +284,19 @@ function awSetInputAndPopupFromArray(inputArray, popupValue, parentNode, templat
 
 function awRemoveRecipients(msgCompFields, recipientType, recipientsList)
 {
-  if (!msgCompFields)
+  if (!msgCompFields || !recipientsList)
     return;
 
-  var recipientArray = msgCompFields.SplitRecipients(recipientsList, false);
-  if (! recipientArray)
-    return;
+  var recipientArray = msgCompFields.splitRecipients(recipientsList, false, {});
 
-  for ( var index = 0; index < recipientArray.count; index++ )
+  for (var index = 0; index < recipientArray.length; index++)
     for (var row = 1; row <= top.MAX_RECIPIENTS; row ++)
     {
       var popup = awGetPopupElement(row);
       if (popup.selectedItem.getAttribute("value") == recipientType)
       {
         var input = awGetInputElement(row);
-        if (input.value == recipientArray.StringAt(index))
+        if (input.value == recipientArray[index])
         {
           awSetInputAndPopupValue(input, "", popup, "addr_to", -1);
           break;
@@ -295,39 +307,36 @@ function awRemoveRecipients(msgCompFields, recipientType, recipientsList)
 
 function awAddRecipients(msgCompFields, recipientType, recipientsList)
 {
-  if (!msgCompFields)
+  if (!msgCompFields || !recipientsList)
     return;
+  var recipientArray = msgCompFields.splitRecipients(recipientsList, false, {});
 
-  var recipientArray = msgCompFields.SplitRecipients(recipientsList, false);
-  if (! recipientArray)
-    return;
-
-  for ( var index = 0; index < recipientArray.count; index++ )
-    awAddRecipient(recipientType, recipientArray.StringAt(index));
+  for (var index = 0; index < recipientArray.length; index++)
+    awAddRecipient(recipientType, recipientArray[index]);
 }
 
 // this was broken out of awAddRecipients so it can be re-used...adds a new row matching recipientType and
 // drops in the single address.
 function awAddRecipient(recipientType, address)
-{ 
+{
   for (var row = 1; row <= top.MAX_RECIPIENTS; row ++)
   {
     if (awGetInputElement(row).value == "")
       break;
   }
-  
+
   if (row > top.MAX_RECIPIENTS)
     awAppendNewRow(false);
 
   awSetInputAndPopupValue(awGetInputElement(row), address, awGetPopupElement(row), recipientType, row);
- 
+
   /* be sure we still have an empty row left at the end */
   if (row == top.MAX_RECIPIENTS)
   {
     awAppendNewRow(true);
     awSetInputAndPopupValue(awGetInputElement(top.MAX_RECIPIENTS), "", awGetPopupElement(top.MAX_RECIPIENTS), "addr_to", top.MAX_RECIPIENTS);
   }
-  
+
   // add the recipient to our spell check ignore list
   addRecipientsToIgnoreList(address);
 }
@@ -375,7 +384,7 @@ function awTestRowSequence()
 function awResetAllRows()
 {
   var maxRecipients = top.MAX_RECIPIENTS;
-  
+
   for (var row = 1; row <= maxRecipients ; row ++)
   {
     awGetInputElement(row).value = "";
@@ -392,11 +401,10 @@ function awCleanupRows()
   {
     var inputElem = awGetInputElement(row);
     if (inputElem.value == "" && row < maxRecipients)
-      awRemoveRow(row, 1);
+      awRemoveRow(awGetRowByInputElement(inputElem));
     else
     {
-      inputElem.setAttribute("id", "addressCol2#" + rowID);
-      awGetPopupElement(row).setAttribute("id", "addressCol1#" + rowID);
+      awSetInputAndPopupId(inputElem, awGetPopupElement(row), rowID);
       rowID ++;
     }
   }
@@ -410,10 +418,9 @@ function awDeleteRow(rowToDelete)
   var maxRecipients = top.MAX_RECIPIENTS;
   awRemoveRow(rowToDelete);
 
-  var numberOfCols = awGetNumberOfCols();
+  // assume 2 column update (input and popup)
   for (var row = rowToDelete + 1; row <= maxRecipients; row ++)
-    for (var col = 1; col <= numberOfCols; col++)
-      awGetElementByCol(row, col).setAttribute("id", "addressCol" + (col) + "#" + (row-1));
+    awSetInputAndPopupId(awGetInputElement(row), awGetPopupElement(row), (row-1));
 
   awTestRowSequence();
 }
@@ -516,15 +523,14 @@ function awAppendNewRow(setFocus)
     if ( input && input.length == 1 )
     {
       input[0].setAttribute("value", "");
-      input[0].setAttribute("id", "addressCol2#" + top.MAX_RECIPIENTS);
-    
-      //this copies the autocomplete sessions list from recipient#1 
+
+      //this copies the autocomplete sessions list from recipient#1
       input[0].syncSessions(document.getElementById('addressCol2#1'));
 
-  	  // also clone the showCommentColumn setting
-  	  //
-  	  input[0].showCommentColumn = 
-	      document.getElementById("addressCol2#1").showCommentColumn;
+      // also clone the showCommentColumn setting
+      //
+      input[0].showCommentColumn =
+        document.getElementById("addressCol2#1").showCommentColumn;
 
       // We always clone the first row.  The problem is that the first row
       // could be focused.  When we clone that row, we end up with a cloned
@@ -541,7 +547,7 @@ function awAppendNewRow(setFocus)
     var select = newNode.getElementsByTagName(awSelectElementName());
     if ( select && select.length == 1 )
     {
-      // It only makes sense to clone some field types; others 
+      // It only makes sense to clone some field types; others
       // should not be cloned, since it just makes the user have
       // to go to the trouble of selecting something else. In such
       // cases let's default to 'To' (a reasonable default since
@@ -552,7 +558,7 @@ function awAppendNewRow(setFocus)
         case  "addr_reply":
         case  "addr_other":
           select[0].selectedIndex = awGetSelectItemIndex("addr_to");
-          break;       
+          break;
         case "addr_followup":
           select[0].selectedIndex = awGetSelectItemIndex("addr_newsgroups");
           break;
@@ -560,8 +566,9 @@ function awAppendNewRow(setFocus)
         // e.g. "addr_to","addr_cc","addr_bcc","addr_newsgroups":
           select[0].selectedIndex = awGetSelectItemIndex(lastRecipientType);
       }
-    
-      select[0].setAttribute("id", "addressCol1#" + top.MAX_RECIPIENTS);
+
+      awSetInputAndPopupId(input[0], select[0], top.MAX_RECIPIENTS);
+
       if (input)
         _awSetAutoComplete(select[0], input[0]);
     }
@@ -652,46 +659,30 @@ function awSetFocus(row, inputElement)
 {
   top.awRow = row;
   top.awInputElement = inputElement;
-  top.awFocusRetry = 0;
-  setTimeout("_awSetFocus();", 0);
+  setTimeout(_awSetFocus, 0);
 }
 
 function _awSetFocus()
 {
   var listbox = document.getElementById('addressingWidget');
-  //try
-  //{
-    var theNewRow = awGetListItem(top.awRow);
+  var theNewRow = awGetListItem(top.awRow);
 
-    //Warning: firstVisibleRow is zero base but top.awRow is one base!
-    var firstVisibleRow = listbox.getIndexOfFirstVisibleRow();
-    var numOfVisibleRows = listbox.getNumberOfVisibleRows();
+  // Warning: firstVisibleRow is zero base but top.awRow is one base!
+  var firstVisibleRow = listbox.getIndexOfFirstVisibleRow();
+  var numOfVisibleRows = listbox.getNumberOfVisibleRows();
 
-    //Do we need to scroll in order to see the selected row?
-    if (top.awRow <= firstVisibleRow)
-      listbox.scrollToIndex(top.awRow - 1);
-    else
-      if (top.awRow - 1 >= (firstVisibleRow + numOfVisibleRows))
-        listbox.scrollToIndex(top.awRow - numOfVisibleRows);
+  // Do we need to scroll in order to see the selected row?
+  if (top.awRow <= firstVisibleRow)
+    listbox.scrollToIndex(top.awRow - 1);
+  else if (top.awRow - 1 >= (firstVisibleRow + numOfVisibleRows))
+    listbox.scrollToIndex(top.awRow - numOfVisibleRows);
 
-    top.awInputElement.focus();
-  /*}
-  catch(ex)
-  {
-    top.awFocusRetry ++;
-    if (top.awFocusRetry < 3)
-    {
-      dump("_awSetFocus failed, try it again...\n");
-      setTimeout("_awSetFocus();", 0);
-    }
-    else
-      dump("_awSetFocus failed, forget about it!\n");
-  }*/
+  top.awInputElement.focus();
 }
 
 function awTabFromRecipient(element, event)
 {
-  //If we are the last element in the listbox, we don't want to create a new row.
+  // If we are the last element in the listbox, we don't want to create a new row.
   if (element == awGetInputElement(top.MAX_RECIPIENTS))
     top.doNotCreateANewRow = true;
 
@@ -727,7 +718,7 @@ function DragOverAddressingWidget(event)
   var validFlavor = false;
   var dragSession = dragSession = gDragService.getCurrentSession();
 
-  if (dragSession.isDataFlavorSupported("text/x-moz-address")) 
+  if (dragSession.isDataFlavorSupported("text/x-moz-address"))
     validFlavor = true;
 
   if (validFlavor)
@@ -737,7 +728,7 @@ function DragOverAddressingWidget(event)
 function DropOnAddressingWidget(event)
 {
   var dragSession = gDragService.getCurrentSession();
-  
+
   var trans = Components.classes["@mozilla.org/widget/transferable;1"].createInstance(Components.interfaces.nsITransferable);
   trans.addDataFlavor("text/x-moz-address");
 
@@ -748,9 +739,9 @@ function DropOnAddressingWidget(event)
     var bestFlavor = new Object();
     var len = new Object();
     trans.getAnyTransferData ( bestFlavor, dataObj, len );
-    if ( dataObj )  
+    if ( dataObj )
       dataObj = dataObj.value.QueryInterface(Components.interfaces.nsISupportsString);
-    if ( !dataObj ) 
+    if ( !dataObj )
       continue;
 
     // pull the address out of the data object
@@ -770,7 +761,9 @@ function DropRecipient(target, recipient)
 
 function _awSetAutoComplete(selectElem, inputElem)
 {
-  inputElem.disableAutocomplete = selectElem.value == 'addr_newsgroups' || selectElem.value == 'addr_followup' || selectElem.value == 'addr_other';
+  inputElem.disableAutoComplete = selectElem.value == 'addr_newsgroups' ||
+                                  selectElem.value == 'addr_followup' ||
+                                  selectElem.value == 'addr_other';
 }
 
 function awSetAutoComplete(rowNumber)
@@ -789,7 +782,7 @@ function awRecipientTextCommand(userAction, element)
 // Called when an autocomplete session item is selected and the status of
 // the session it was selected from is nsIAutoCompleteStatus::failureItems.
 //
-// As of this writing, the only way that can happen is when an LDAP 
+// As of this writing, the only way that can happen is when an LDAP
 // autocomplete session returns an error to be displayed to the user.
 //
 // There are hardcoded messages in here, but these are just fallbacks for
@@ -797,37 +790,34 @@ function awRecipientTextCommand(userAction, element)
 //
 function awRecipientErrorCommand(errItem, element)
 {
-  // remove the angle brackets from the general error message to construct 
+  // remove the angle brackets from the general error message to construct
   // the title for the alert.  someday we'll pass this info using a real
   // exception object, and then this code can go away.
   //
   var generalErrString;
-  if (errItem.value != "") 
+  if (errItem.value != "")
     generalErrString = errItem.value.slice(1, errItem.value.length-1);
-  else 
-    generalErrString = "Unknown LDAP server problem encountered";	
+  else
+    generalErrString = "Unknown LDAP server problem encountered";
 
   // try and get the string of the specific error to contruct the complete
   // err msg, otherwise fall back to something generic.  This message is
-  // handed to us as an nsISupportsString in the param slot of the 
-  // autocomplete error item, by agreement documented in 
+  // handed to us as an nsISupportsString in the param slot of the
+  // autocomplete error item, by agreement documented in
   // nsILDAPAutoCompFormatter.idl
   //
   var specificErrString = "";
-  try 
+  try
   {
     var specificError = errItem.param.QueryInterface(Components.interfaces.nsISupportsString);
-	  specificErrString = specificError.data;
-  } catch (ex) 
+    specificErrString = specificError.data;
+  } catch (ex)
   {}
-  
-  if (specificErrString == "") 
-	  specificErrString = "Internal error";
 
-  if (gPromptService) 
-    gPromptService.alert(window, generalErrString, specificErrString);
-  else 
-	  window.alert(generalErrString + ": " + specificErrString);
+  if (specificErrString == "")
+    specificErrString = "Internal error";
+
+  gPromptService.alert(window, generalErrString, specificErrString);
 }
 
 function awRecipientKeyPress(event, element)
@@ -841,7 +831,7 @@ function awRecipientKeyPress(event, element)
     break;
   case KeyEvent.DOM_VK_RETURN:
   case KeyEvent.DOM_VK_TAB:
-    // if the user text contains a comma or a line return, ignore 
+    // if the user text contains a comma or a line return, ignore
     if (element.value.search(',') != -1)
     {
       var addresses = element.value;
@@ -850,7 +840,7 @@ function awRecipientKeyPress(event, element)
     }
     else if (event.keyCode == KeyEvent.DOM_VK_TAB)
       awTabFromRecipient(element, event);
-    
+
     break;
   }
 }
@@ -871,8 +861,8 @@ function awArrowHit(inputElement, direction)
 function awRecipientKeyDown(event, element)
 {
   switch(event.keyCode) {
-  case 46:
-  case 8:
+  case KeyEvent.DOM_VK_DELETE:
+  case KeyEvent.DOM_VK_BACK_SPACE:
     /* do not query directly the value of the text field else the autocomplete widget could potentially
        alter it value while doing some internal cleanup, instead, query the value through the first child
     */
@@ -889,8 +879,8 @@ function awRecipientKeyDown(event, element)
 function awKeyDown(event, listboxElement)
 {
   switch(event.keyCode) {
-  case 46:
-  case 8:
+  case KeyEvent.DOM_VK_DELETE:
+  case KeyEvent.DOM_VK_BACK_SPACE:
     /* Warning, the listboxElement.selectedItems will change everytime we delete a row */
     var selItems = listboxElement.selectedItems;
     var length = listboxElement.selectedItems.length;
@@ -906,7 +896,7 @@ function awKeyDown(event, listboxElement)
 function awMenulistKeyPress(event, element)
 {
   switch(event.keyCode) {
-  case 9:
+  case KeyEvent.DOM_VK_TAB:
     awTabFromMenulist(element, event);
     break;
   }
@@ -1016,7 +1006,7 @@ function awSizerMouseMove()
 
 function awSizerMouseUp()
 {
-  document.removeEventListener("mousemove", awSizerMouseUp, false);
+  document.removeEventListener("mousemove", awSizerMouseMove, true);
   document.removeEventListener("mouseup", awSizerMouseUp, false);
 }
 
@@ -1031,8 +1021,8 @@ function awDocumentKeyPress(event)
 
 function awRecipientInputCommand(event, inputElement)
 {
-  gContentChanged=true; 
-  setupAutocomplete(); 
+  gContentChanged=true;
+  setupAutocomplete();
 }
 
 // Given an arbitrary block of text like a comma delimited list of names or a names separated by spaces,
@@ -1068,8 +1058,8 @@ function AutomatedAutoCompleteHandler()
 {
 }
 
-// state driven self contained object which will autocomplete a block of addresses without any UI. 
-// force picks the first match and adds it to the addressing widget, then goes on to the next 
+// state driven self contained object which will autocomplete a block of addresses without any UI.
+// force picks the first match and adds it to the addressing widget, then goes on to the next
 // name to complete.
 
 AutomatedAutoCompleteHandler.prototype =
@@ -1106,10 +1096,12 @@ AutomatedAutoCompleteHandler.prototype =
 
     if (this.indexIntoNames < this.numNamesToComplete && this.namesToComplete[this.indexIntoNames])
     {
+      /* XXX This is used to work, until switching to the new toolkit broke it
+         We should fix it see bug 456550.
       if (this.namesToComplete[this.indexIntoNames].search('@') == -1) // don't autocomplete if address has an @ sign in it
       {
         // make sure total session count is updated before we kick off ANY actual searches
-        if (gAutocompleteSession) 
+        if (gAutocompleteSession)
           this.numSessionsToSearch++;
 
         if (gLDAPSession && gCurrentAutocompleteDirectory)
@@ -1133,23 +1125,24 @@ AutomatedAutoCompleteHandler.prototype =
         if (gLDAPSession && gCurrentAutocompleteDirectory)
           gLDAPSession.onStartLookup(this.namesToComplete[this.indexIntoNames], null, this);
       }
+      */
 
       if (!this.numSessionsToSearch)
         this.processAllResults(); // ldap and ab are turned off, so leave text alone
     }
   },
 
-  onStatus:function(aStatus) 
+  onStatus:function(aStatus)
   {
     return;
   },
-  
-  onAutoComplete: function(aResults, aStatus) 
+
+  onAutoComplete: function(aResults, aStatus)
   {
     // store the results until all sessions are done and have reported in
     if (aResults)
       this.searchResults[this.numSessionsSearched] = aResults;
-    
+
     this.numSessionsSearched++; // bump our counter
 
     if (this.numSessionsToSearch <= this.numSessionsSearched)
@@ -1162,7 +1155,7 @@ AutomatedAutoCompleteHandler.prototype =
     var addressToAdd;
 
     // loop through the results looking for the non default case (default case is the address book with only one match, the default domain)
-    var sessionIndex; 
+    var sessionIndex;
 
     var searchResultsForSession;
 
@@ -1195,8 +1188,8 @@ AutomatedAutoCompleteHandler.prototype =
       addressToAdd = this.namesToComplete[this.indexIntoNames];
 
     // that will automatically set the focus on a new available row, and make sure it is visible
-    awAddRecipient(this.recipientType ? this.recipientType : "addr_to", addressToAdd);  
-    
+    awAddRecipient(this.recipientType ? this.recipientType : "addr_to", addressToAdd);
+
     this.indexIntoNames++;
     this.autoCompleteNextAddress();
   },
