@@ -1,8 +1,9 @@
-//@line 36 "/usr/obj/i386/mozilla-thunderbird-2.0.0.23p1/mozilla/mail/components/migration/content/migration.js"
+//@line 36 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/components/migration/content/migration.js"
 
 const kIMig = Components.interfaces.nsIMailProfileMigrator;
 const kIPStartup = Components.interfaces.nsIProfileStartup;
 const kProfileMigratorContractIDPrefix = "@mozilla.org/profile/migrator;1?app=mail&type=";
+const nsISupportsString = Components.interfaces.nsISupportsString;
 
 var MigrationWizard = {
   _source: "",                  // Source Profile Migrator ContractID suffix
@@ -20,39 +21,39 @@ var MigrationWizard = {
     os.addObserver(this, "Migration:ItemAfterMigrate", false);
     os.addObserver(this, "Migration:Ended", false);
     os.addObserver(this, "Migration:Progress", false);
-    
+
     this._wiz = document.documentElement;
 
     if ("arguments" in window) {
       this._source = window.arguments[0];
       this._migrator = window.arguments[1] ? window.arguments[1].QueryInterface(kIMig) : null;
       this._autoMigrate = window.arguments[2].QueryInterface(kIPStartup);
-      
+
       // Show the "nothing" option in the automigrate case to provide an
       // easily identifiable way to avoid migration and create a new profile.
       var nothing = document.getElementById("nothing");
-      nothing.hidden = false;      
+      nothing.hidden = false;
     }
 
     this.onImportSourcePageShow();
-	
+
     // Behavior alert! If we were given a migrator already, then we are going to perform migration
-    // with that migrator, skip the wizard screen where we show all of the migration sources and 
+    // with that migrator, skip the wizard screen where we show all of the migration sources and
     // jump right into migration.
     if (this._migrator)
     {
       if (this._migrator.sourceHasMultipleProfiles)
         this._wiz.goTo("selectProfile");
-      else 
+      else
       {
         var sourceProfiles = this._migrator.sourceProfiles;
-        var profileName = sourceProfiles.QueryElementAt(0, Components.interfaces.nsISupportsString);
-        this._selectedProfile = profileName.data;
+        this._selectedProfile = sourceProfiles
+          .queryElementAt(0, nsISupportsString).data;
         this._wiz.goTo("migrating");
       }
     }
   },
-  
+
   uninit: function ()
   {
     var os = Components.classes["@mozilla.org/observer-service;1"].getService(Components.interfaces.nsIObserverService);
@@ -62,12 +63,12 @@ var MigrationWizard = {
     os.removeObserver(this, "Migration:Ended");
     os.removeObserver(this, "Migration:Progress");
   },
-  
+
   // 1 - Import Source
   onImportSourcePageShow: function ()
   {
     this._wiz.canRewind = false;
-    
+
     // Figure out what source apps are are available to import from:
     var group = document.getElementById("importSourceGroup");
     for (var i = 0; i < group.childNodes.length; ++i) {
@@ -81,26 +82,26 @@ var MigrationWizard = {
         }
       }
     }
-    
+
     var firstNonDisabled = null;
     for (var i = 0; i < group.childNodes.length; ++i) {
-	  if (!group.childNodes[i].hidden) {
+    if (!group.childNodes[i].hidden) {
         firstNonDisabled = group.childNodes[i];
         break;
       }
     }
     group.selectedItem = this._source == "" ? firstNonDisabled : document.getElementById(this._source);
   },
-  
+
   onImportSourcePageAdvanced: function ()
   {
     var newSource = document.getElementById("importSourceGroup").selectedItem.id;
-    
+
     if (newSource == "nothing") {
       document.documentElement.cancel();
       return;
     }
-    
+
     if (!this._migrator || (newSource != this._source)) {
       // Create the migrator for the selected source.
       var contractID = kProfileMigratorContractIDPrefix + newSource;
@@ -109,24 +110,23 @@ var MigrationWizard = {
       this._itemsFlags = kIMig.ALL;
       this._selectedProfile = null;
     }
-    
+
       this._source = newSource;
-      
+
     // check for more than one source profile
     if (this._migrator.sourceHasMultipleProfiles)
       this._wiz.currentPage.next = "selectProfile";
     else {
       this._wiz.currentPage.next = "migrating";
       var sourceProfiles = this._migrator.sourceProfiles;
-      if (sourceProfiles && sourceProfiles.Count() == 1) {
-        var profileName = sourceProfiles.QueryElementAt(0, Components.interfaces.nsISupportsString);
-        this._selectedProfile = profileName.data;
-      }
+      if (sourceProfiles && sourceProfiles.length == 1)
+        this._selectedProfile =
+          sourceProfiles.queryElementAt(0, nsISupportsString).data;
       else
         this._selectedProfile = "";
     }
   },
-  
+
   // 2 - [Profile Selection]
   onSelectProfilePageShow: function ()
   {
@@ -134,49 +134,48 @@ var MigrationWizard = {
     // too and don't want to disable the back button
     // if (this._autoMigrate)
     //   document.documentElement.getButton("back").disabled = true;
-      
+
     var profiles = document.getElementById("profiles");
-    while (profiles.hasChildNodes()) 
+    while (profiles.hasChildNodes())
       profiles.removeChild(profiles.firstChild);
-    
+
     var sourceProfiles = this._migrator.sourceProfiles;
-    var count = sourceProfiles.Count();
+    var count = sourceProfiles.length;
     for (var i = 0; i < count; ++i) {
       var item = document.createElement("radio");
-      var str = sourceProfiles.QueryElementAt(i, Components.interfaces.nsISupportsString);
-      item.id = str.data;
-      item.setAttribute("label", str.data);
+      item.id = sourceProfiles.queryElementAt(i, nsISupportsString).data;
+      item.setAttribute("label", item.id);
       profiles.appendChild(item);
     }
-    
+
     profiles.selectedItem = this._selectedProfile ? document.getElementById(this._selectedProfile) : profiles.firstChild;
   },
-  
+
   onSelectProfilePageRewound: function ()
   {
     var profiles = document.getElementById("profiles");
     this._selectedProfile = profiles.selectedItem.id;
   },
-  
+
   onSelectProfilePageAdvanced: function ()
   {
     var profiles = document.getElementById("profiles");
     this._selectedProfile = profiles.selectedItem.id;
-    
+
     // If we're automigrating, don't show the item selection page, just grab everything.
     if (this._autoMigrate)
       this._wiz.currentPage.next = "migrating";
   },
-  
+
   // 3 - ImportItems
   onImportItemsPageShow: function ()
   {
     var dataSources = document.getElementById("dataSources");
     while (dataSources.hasChildNodes())
       dataSources.removeChild(dataSources.firstChild);
-    
+
     var bundle = document.getElementById("bundle");
-    
+
     var items = this._migrator.getMigrateData(this._selectedProfile, this._autoMigrate);
     for (var i = 0; i < 16; ++i) {
       var itemID = (items >> i) & 0x1 ? Math.pow(2, i) : 0;
@@ -201,7 +200,7 @@ var MigrationWizard = {
         this._itemsFlags |= parseInt(checkbox.id);
     }
   },
-  
+
   onImportItemCommand: function (aEvent)
   {
     var items = document.getElementById("dataSources");
@@ -217,33 +216,35 @@ var MigrationWizard = {
 
     this._wiz.canAdvance = oneChecked;
   },
-  
+
   // 4 - Migrating
   onMigratingPageShow: function ()
   {
     this._wiz.getButton("cancel").disabled = true;
     this._wiz.canRewind = false;
     this._wiz.canAdvance = false;
-    
-    // When automigrating, show all of the data that can be received from this source.
-    if (this._autoMigrate)
-      this._itemsFlags = this._migrator.getMigrateData(this._selectedProfile, this._autoMigrate);
+
+    // When automigrating or migrating all, show all of the data that can
+    // be received from this source.
+    if (this._autoMigrate || this._itemsFlags == kIMig.ALL)
+      this._itemsFlags = this._migrator.getMigrateData(this._selectedProfile,
+                                                       this._autoMigrate);
 
     this._listItems("migratingItems");
     setTimeout(this.onMigratingMigrate, 0, this);
   },
-  
+
   onMigratingMigrate: function (aOuter)
   {
     aOuter._migrator.migrate(aOuter._itemsFlags, aOuter._autoMigrate, aOuter._selectedProfile);
   },
-  
+
   _listItems: function (aID)
   {
     var items = document.getElementById(aID);
     while (items.hasChildNodes())
       items.removeChild(items.firstChild);
-    
+
     var bundle = document.getElementById("bundle");
     var itemID;
     for (var i = 0; i < 16; ++i) {
@@ -257,13 +258,13 @@ var MigrationWizard = {
         }
         catch (e) {
           // if the block above throws, we've enumerated all the import data types we
-          // currently support and are now just wasting time, break. 
+          // currently support and are now just wasting time, break.
           break;
         }
       }
     }
   },
-  
+
   observe: function (aSubject, aTopic, aData)
   {
     switch (aTopic) {
@@ -288,7 +289,7 @@ var MigrationWizard = {
         // We're done now.
         this._wiz.canAdvance = true;
         this._wiz.advance();
-        setTimeout("close()", 5000);
+        setTimeout(window.close, 5000);
       }
       else {
         this._wiz.canAdvance = true;
@@ -301,7 +302,7 @@ var MigrationWizard = {
       break;
     }
   },
-  
+
   onDonePageShow: function ()
   {
     this._wiz.getButton("cancel").disabled = true;
