@@ -1,15 +1,15 @@
-//@line 39 "/usr/obj/ports/mozilla-thunderbird-2.0.0.23p1/mozilla/mail/components/preferences/downloads.js"
+//@line 40 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/components/preferences/downloads.js"
 
-var gDownloadsPane = {
+var gDownloadDirSection = {
   chooseFolder: function ()
   {
     const nsIFilePicker = Components.interfaces.nsIFilePicker;
     var fp = Components.classes["@mozilla.org/filepicker;1"]
                        .createInstance(nsIFilePicker);
     var bundlePreferences = document.getElementById("bundlePreferences");
-    var title = bundlePreferences.getString("chooseDownloadFolderTitle");
+    var title = bundlePreferences.getString("chooseAttachmentsFolderTitle");
     fp.init(window, title, nsIFilePicker.modeGetFolder);
-    
+
     const nsILocalFile = Components.interfaces.nsILocalFile;
     var customDirPref = document.getElementById("browser.download.dir");
     if (customDirPref.value)
@@ -23,26 +23,26 @@ var gDownloadsPane = {
       folderListPref.value = this._fileToIndex(file);
     }
   },
-  
+
   onReadUseDownloadDir: function ()
   {
     var downloadFolder = document.getElementById("downloadFolder");
     var chooseFolder = document.getElementById("chooseFolder");
     var preference = document.getElementById("browser.download.useDownloadDir");
     downloadFolder.disabled = !preference.value;
-    chooseFolder.disabled = !preference.value;      
+    chooseFolder.disabled = !preference.value;
     return undefined;
   },
-  
+
   _fileToIndex: function (aFile)
-  { 
+  {
     if (!aFile || aFile.equals(this._getDownloadsFolder("Desktop")))
       return 0;
     else if (aFile.equals(this._getDownloadsFolder("Downloads")))
       return 1;
     return 2;
   },
-  
+
   _indexToFile: function (aIndex)
   {
     switch (aIndex) {
@@ -54,7 +54,7 @@ var gDownloadsPane = {
     var customDirPref = document.getElementById("browser.download.dir");
     return customDirPref.value;
   },
-  
+
   _getSpecialFolderKey: function (aFolderType)
   {
     if (aFolderType == "Desktop")
@@ -63,30 +63,23 @@ var gDownloadsPane = {
     if (aFolderType != "Downloads")
       throw "ASSERTION FAILED: folder type should be 'Desktop' or 'Downloads'";
 
-//@line 109 "/usr/obj/ports/mozilla-thunderbird-2.0.0.23p1/mozilla/mail/components/preferences/downloads.js"
+//@line 110 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/components/preferences/downloads.js"
     return "Home";
-//@line 112 "/usr/obj/ports/mozilla-thunderbird-2.0.0.23p1/mozilla/mail/components/preferences/downloads.js"
+//@line 113 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/components/preferences/downloads.js"
   },
 
   _getDownloadsFolder: function (aFolder)
   {
     var fileLocator = Components.classes["@mozilla.org/file/directory_service;1"]
                                 .getService(Components.interfaces.nsIProperties);
-    var dir = fileLocator.get(this._getSpecialFolderKey(aFolder), 
+    var dir = fileLocator.get(this._getSpecialFolderKey(aFolder),
                               Components.interfaces.nsILocalFile);
     if (aFolder != "Desktop")
       dir.append("My Downloads");
-      
+
     return dir;
   },
-  
-  _getDisplayNameOfFile: function (aFolder)
-  {
-    // TODO: would like to add support for 'Downloads on Macintosh HD' 
-    //       for OS X users.
-    return aFolder ? aFolder.path : "";
-  },
-  
+
   readDownloadDirPref: function ()
   {
     var folderListPref = document.getElementById("browser.download.folderList");
@@ -100,8 +93,8 @@ var gDownloadsPane = {
     else if (folderListPref.value == 1 || customIndex == 1) 
       downloadFolder.label = bundlePreferences.getString("myDownloadsFolderName");
     else
-      downloadFolder.label = this._getDisplayNameOfFile(customDirPref.value);
-    
+      downloadFolder.label = customDirPref.value ? customDirPref.value.path : "";
+
     var ios = Components.classes["@mozilla.org/network/io-service;1"]
                         .getService(Components.interfaces.nsIIOService);
     var fph = ios.getProtocolHandler("file")
@@ -110,32 +103,13 @@ var gDownloadsPane = {
     var downloadDir = currentDirPref.value || this._indexToFile(folderListPref.value);
     var urlspec = fph.getURLSpecFromFile(downloadDir);
     downloadFolder.image = "moz-icon://" + urlspec + "?size=16";
-    
+
     return undefined;
   },
-  
+
   writeFolderList: function ()
   {
     var currentDirPref = document.getElementById("browser.download.downloadDir");
     return this._fileToIndex(currentDirPref.value);
-  },
-  
-  showWhenStartingPrefChanged: function ()
-  {
-    document.getElementById("browser.download.manager.closeWhenDone")
-            .disabled = !document.getElementById("browser.download.manager.showWhenStarting").value;
-  },
-  
-  readShowWhenStartingPref: function ()
-  {
-    this.showWhenStartingPrefChanged();
-    return undefined;
-  },
-  
-  showFileTypeActions: function ()
-  {
-    document.documentElement.openWindow("Preferences:DownloadActions",
-                                        "chrome://messenger/content/preferences/downloadactions.xul",
-                                        "", null);
   }
 };
