@@ -1,4 +1,4 @@
-//@line 38 "/usr/obj/i386/mozilla-thunderbird-2.0.0.23p1/mozilla/toolkit/mozapps/preferences/removemp.js"
+//@line 38 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mozilla/toolkit/mozapps/preferences/removemp.js"
 
 var gRemovePasswordDialog = {
   _token    : null,
@@ -12,7 +12,7 @@ var gRemovePasswordDialog = {
                              .getService(Components.interfaces.nsIPromptService);
     this._bundle = document.getElementById("bundlePreferences");
 
-    this._okButton = document.documentElement.getButton("accept")
+    this._okButton = document.documentElement.getButton("accept");
     this._okButton.label = this._bundle.getString("pw_remove_button");
     
     this._password = document.getElementById("password");
